@@ -1,4 +1,3 @@
-
 class Pry
 
   # Manage the processing of command line options
@@ -11,14 +10,16 @@ class Pry
       # @return [Proc] The Proc defining the valid command line options.
       attr_accessor :options
 
-      # @return [Array] The Procs that process the parsed options.
+      # @return [Array] The Procs that process the parsed options. Plugins can
+      #   utilize this facility in order to add and process their own Pry
+      #   options.
       attr_accessor :option_processors
 
       # @return [Array<String>] The input array of strings to process
       #   as CLI options.
       attr_accessor :input_args
 
-      # Add another set of CLI options (a Slop block)
+      # Add another set of CLI options (a Pry::Slop block)
       def add_options(&block)
         if options
           old_options = options
@@ -43,7 +44,7 @@ class Pry
       end
 
       # Add a block responsible for processing parsed options.
-      def process_options(&block)
+      def add_option_processor(&block)
         self.option_processors ||= []
         option_processors << block
 
@@ -56,21 +57,63 @@ class Pry
         self.option_processors = nil
       end
 
-      def parse_options(args=ARGV.dup)
+      def parse_options(args=ARGV)
         unless options
           raise NoOptionsError, "No command line options defined! Use Pry::CLI.add_options to add command line options."
         end
 
+        # Load config files etc first, ensuring that cli options will take precedence.
+        Pry.initial_session_setup
+
         self.input_args = args
 
-        opts = Slop.parse!(args, :help => true, :multiple_switches => false, &options)
+        begin
+          opts = Pry::Slop.parse!(
+            args,
+            :help => true,
+            :multiple_switches => false,
+            :strict => true,
+            &options
+          )
+        rescue Pry::Slop::InvalidOptionError
+          # Display help message on unknown switches and exit.
+          puts Pry::Slop.new(&options)
+          exit
+        end
+
+        Pry.final_session_setup
 
         # Option processors are optional.
         if option_processors
           option_processors.each { |processor| processor.call(opts) }
         end
 
-        self
+        opts
+      end
+
+      def start(opts)
+        exit if opts.help?
+
+        # invoked via cli
+        Pry.cli = true
+
+        # create the actual context
+        if opts[:context]
+          Pry.initial_session_setup
+          context = Pry.binding_for(eval(opts[:context]))
+          Pry.final_session_setup
+        else
+          context = Pry.toplevel_binding
+        end
+
+        if Pry::CLI.input_args.any? && Pry::CLI.input_args != ["pry"]
+          full_name = File.expand_path(Pry::CLI.input_args.first)
+          Pry.load_file_through_repl(full_name)
+          exit
+        end
+
+        # Start the session (running any code passed with -e, if there is any)
+        Pry.start(context, :input => StringIO.new(Pry.config.exec_string))
       end
 
     end
@@ -80,30 +123,28 @@ class Pry
 end
 
 
-# String that is built to be executed on start (created by -e and -exec switches)
-exec_string = ""
-
 # Bring in options defined by plugins
-Slop.new do
+Pry::Slop.new do
   on "no-plugins" do
     Pry.config.should_load_plugins = false
   end
 end.parse(ARGV.dup)
 
 if Pry.config.should_load_plugins
-  Pry::CLI.add_plugin_options 
+  Pry::CLI.add_plugin_options
 end
 
 # The default Pry command line options (before plugin options are included)
 Pry::CLI.add_options do
   banner %{Usage: pry [OPTIONS]
 Start a Pry session.
-See: `https://github.com/pry` for more information.
-Copyright (c) 2013 John Mair (banisterfiend)
+See http://pryrepl.org/ for more information.
+Copyright (c) 2016 John Mair (banisterfiend)
 --
 }
   on :e, :exec=, "A line of code to execute in context before the session starts" do |input|
-    exec_string << input + "\n"
+    Pry.config.exec_string += "\n" if Pry.config.exec_string.length > 0
+    Pry.config.exec_string += input
   end
 
   on "no-pager", "Disable pager for long output" do
@@ -115,7 +156,7 @@ Copyright (c) 2013 John Mair (banisterfiend)
   end
 
   on "no-color", "Disable syntax highlighting for session" do
-    Pry.color = false
+    Pry.config.color = false
   end
 
   on :f, "Suppress loading of ~/.pryrc and ./.pryrc" do
@@ -136,11 +177,11 @@ Copyright (c) 2013 John Mair (banisterfiend)
     Pry.config.should_load_plugins = false
   end
 
-  on "installed-plugins", "List installed plugins." do
+  on "plugins", "List installed plugins." do
     puts "Installed Plugins:"
     puts "--"
     Pry.locate_plugins.each do |plugin|
-      puts "#{plugin.name}".ljust(18) + plugin.spec.summary
+      puts "#{plugin.name}".ljust(18) << plugin.spec.summary
     end
     exit
   end
@@ -149,6 +190,10 @@ Copyright (c) 2013 John Mair (banisterfiend)
     Pry.config.prompt = Pry::SIMPLE_PROMPT
   end
 
+  on "noprompt", "No prompt mode" do
+    Pry.config.prompt = Pry::NO_PROMPT
+  end
+
   on :r, :require=, "`require` a Ruby script at startup" do |file|
     Pry.config.requires << file
   end
@@ -177,26 +222,4 @@ Copyright (c) 2013 John Mair (banisterfiend)
      "Start the session in the specified context. Equivalent to `context.pry` in a session.",
      :default => "Pry.toplevel_binding"
      )
-end.process_options do |opts|
-
-  exit if opts.help?
-
-  # invoked via cli
-  Pry.cli = true
-
-  # create the actual context
-  context = Pry.binding_for(eval(opts[:context]))
-
-  if Pry::CLI.input_args.any? && Pry::CLI.input_args != ["pry"]
-    full_name = File.expand_path(Pry::CLI.input_args.first)
-    Pry.load_file_through_repl(full_name)
-    exit
-  end
-
-  if Pry.config.should_load_plugins
-    parser = Slop.new
-  end
-
-  # Start the session (running any code passed with -e, if there is any)
-  Pry.start(context, :input => StringIO.new(exec_string))
 end
