@@ -4,6 +4,12 @@ class Pry
 
     command_options :shellwords => false, :interpolate => false
 
+    def initialize(*)
+      super
+
+      @used_super = nil
+    end
+
     def options(opt)
       opt.on :s, :super, "Select the 'super' method. Can be repeated to traverse the ancestors", :as => :count
       opt.on :l, "line-numbers", "Show line numbers"
@@ -16,7 +22,15 @@ class Pry
       raise CommandError, no_definition_message if !code_object
       @original_code_object = code_object
 
-      if show_all_modules?(code_object)
+      if !obj_name && code_object.c_module? && !opts[:all]
+        result = "Warning: You're inside an object, whose class is defined by means\n" +
+                 "         of the C Ruby API. Pry cannot display the information for\n" +
+                 "         this class."
+        if code_object.candidates.any?
+          result += "\n         However, you can view monkey-patches applied to this class.\n" +
+                    "         Just execute the same command with the '--all' switch."
+        end
+      elsif show_all_modules?(code_object)
         # show all monkey patches for a module
 
         result = content_and_headers_for_all_module_candidates(code_object)
@@ -79,7 +93,7 @@ class Pry
     end
 
     def no_definition_message
-      "Couldn't locate a definition for #{obj_name}!"
+      "Couldn't locate a definition for #{obj_name}"
     end
 
     # Generate a header (meta-data information) for all the code
