@@ -66,8 +66,10 @@ class Pry
     #
     # :reserved and :keywords are the CodeRay 0.9.8 and 1.0.0 respectively
     # classifications of "super", "next", "return", etc.
-    STATEMENT_END_TOKENS = IGNORE_TOKENS + [:regexp, :integer, :float, :keyword,
-                                            :delimiter, :reserved]
+    STATEMENT_END_TOKENS = IGNORE_TOKENS + [:regexp, :integer, :float,
+                                            :keyword, :delimiter, :reserved,
+                                            :instance_variable,
+                                            :class_variable, :global_variable]
 
     # Collection of tokens that should appear dedented even though they
     # don't affect the surrounding code.
@@ -94,8 +96,8 @@ class Pry
       indent = new
       lines = str.split("\n")
       n = line_number - 1
-      to_indent = lines[0...n] + (lines[n] || "").split("def").first(1)
-      indent.indent(to_indent.join("\n") + "\n")
+      to_indent = lines[0...n] << (lines[n] || "").split("def").first(1)
+      indent.indent(to_indent.join("\n") << "\n")
       indent.module_nesting
     end
 
@@ -223,6 +225,8 @@ class Pry
 
         seen_for_at << add_after if OPTIONAL_DO_TOKENS.include?(token)
 
+        next if is_singleline_if
+
         if kind == :delimiter
           track_delimiter(token)
         elsif OPEN_TOKENS.keys.include?(token) && !is_optional_do && !is_singleline_if
@@ -320,7 +324,7 @@ class Pry
     # [ ["class", "Foo"], ["module", "Bar::Baz"], ["class <<", "self"] ]
     #
     # A nil value in the @module_nesting array happens in two places: either
-    # when @awaiting_token is true and we're still waiting for the string to
+    # when @awaiting_class is true and we're still waiting for the string to
     # fill that space, or when a parse was rejected.
     #
     # At the moment this function is quite restricted about what formats it will
@@ -341,7 +345,7 @@ class Pry
           @module_nesting.last[1] = token if kind == :class
           @awaiting_class = false
         else
-          # leave @nesting[-1][
+          # leave @module_nesting[-1]
           @awaiting_class = false
         end
       end
@@ -384,13 +388,13 @@ class Pry
     # @return [String]
     def correct_indentation(prompt, code, overhang=0)
       prompt = prompt.delete("\001\002")
-      full_line = prompt + code
+      line_to_measure = Pry::Helpers::Text.strip_color(prompt) << code
       whitespace = ' ' * overhang
 
       _, cols = Terminal.screen_size
 
       cols = cols.to_i
-      lines = cols != 0 ? (full_line.length / cols + 1) : 1
+      lines = (cols != 0 ? (line_to_measure.length / cols + 1) : 1).to_i
 
       if Pry::Helpers::BaseHelpers.windows_ansi?
         move_up   = "\e[#{lines}F"
