@@ -15,21 +15,21 @@ describe Pry::CommandSet do
 
   describe "[]=" do
     it "removes a command from the command set" do
-      @set["help"].should_not == nil
+      expect(@set["help"]).not_to eq nil
       @set["help"] = nil
-      @set["help"].should == nil
+      expect(@set["help"]).to eq nil
       expect { @set.run_command(TOPLEVEL_BINDING, "help") }.to raise_error Pry::NoCommandError
     end
 
     it "replaces a command" do
       old_help = @set["help"]
       @set["help"] = @set["pry-version"]
-      @set["help"].should_not == old_help
+      expect(@set["help"]).not_to eq old_help
     end
 
     it "rebinds the command with key" do
       @set["help-1"] = @set["help"]
-      @set["help-1"].match.should == "help-1"
+      expect(@set["help-1"].match).to eq "help-1"
     end
 
     it "raises a TypeError when command is not a subclass of Pry::Command" do
@@ -44,25 +44,24 @@ describe Pry::CommandSet do
     end
 
     @set.run_command @ctx, 'foo'
-    run.should == true
+    expect(run).to eq true
   end
 
   it 'should pass arguments of the command to the block' do
-    @set.command 'foo' do |*args|
-      args.should == [1, 2, 3]
-    end
-
-    @set.run_command @ctx, 'foo', 1, 2, 3
+    expect { |probe|
+      @set.command('foo', &probe)
+      @set.run_command(@ctx, 'foo', 1, 2, 3)
+    }.to yield_with_args(1, 2, 3)
   end
 
   it 'should use the first argument as context' do
-    ctx = @ctx
+    inside = inner_scope do |probe|
+      @set.command('foo', &probe)
 
-    @set.command 'foo' do
-      self.context.should == ctx
+      @set.run_command @ctx, 'foo'
     end
 
-    @set.run_command @ctx, 'foo'
+    expect(inside.context).to eq(@ctx)
   end
 
   it 'should raise an error when calling an undefined command' do
@@ -95,7 +94,7 @@ describe Pry::CommandSet do
     @set.import_from(other_set, 'foo')
 
     @set.run_command @ctx, 'foo'
-    run.should == true
+    expect(run).to eq true
 
     expect { @set.run_command @ctx, 'bar' }.to raise_error Pry::NoCommandError
   end
@@ -108,7 +107,7 @@ describe Pry::CommandSet do
       command('bar') {}
     end
 
-    @set.import(other_set).should == @set
+    expect(@set.import(other_set)).to eq @set
   end
 
   it 'should return command set after import_from' do
@@ -119,7 +118,7 @@ describe Pry::CommandSet do
       command('bar') {}
     end
 
-    @set.import_from(other_set, 'foo').should == @set
+    expect(@set.import_from(other_set, 'foo')).to eq @set
   end
 
   it 'should be able to import some commands from other sets using listing name' do
@@ -132,7 +131,7 @@ describe Pry::CommandSet do
     @set.import_from(other_set, 'foo')
 
     @set.run_command @ctx, /^foo1/
-    run.should == true
+    expect(run).to eq true
   end
 
   it 'should be able to import a whole set' do
@@ -147,7 +146,7 @@ describe Pry::CommandSet do
 
     @set.run_command @ctx, 'foo'
     @set.run_command @ctx, 'bar'
-    run.should == [true, true]
+    expect(run).to eq [true, true]
   end
 
   it 'should be able to import sets at creation' do
@@ -155,12 +154,12 @@ describe Pry::CommandSet do
     @set.command('foo') { run = true }
 
     Pry::CommandSet.new(@set).run_command @ctx, 'foo'
-    run.should == true
+    expect(run).to eq true
   end
 
   it 'should set the descriptions of commands' do
     @set.command('foo', 'some stuff') {}
-    @set['foo'].description.should == 'some stuff'
+    expect(@set['foo'].description).to eq 'some stuff'
   end
 
   describe "aliases" do
@@ -169,11 +168,11 @@ describe Pry::CommandSet do
       @set.command('foo', 'stuff') { run = true }
 
       @set.alias_command 'bar', 'foo'
-      @set['bar'].match.should == 'bar'
-      @set['bar'].description.should == 'Alias for `foo`'
+      expect(@set['bar'].match).to eq 'bar'
+      expect(@set['bar'].description).to eq 'Alias for `foo`'
 
       @set.run_command @ctx, 'bar'
-      run.should == true
+      expect(run).to eq true
     end
 
     it "should be able to alias command with command_prefix" do
@@ -184,11 +183,11 @@ describe Pry::CommandSet do
         @set.alias_command 'owlet', 'owl'
 
         Pry.config.command_prefix = '%'
-        @set['%owlet'].match.should == 'owlet'
-        @set['%owlet'].description.should == 'Alias for `owl`'
+        expect(@set['%owlet'].match).to eq 'owlet'
+        expect(@set['%owlet'].description).to eq 'Alias for `owl`'
 
         @set.run_command @ctx, 'owlet'
-        run.should == true
+        expect(run).to eq true
       ensure
         Pry.config.command_prefix = ''
       end
@@ -199,12 +198,12 @@ describe Pry::CommandSet do
       @set.command('foo', 'stuff', :shellwords => true, :interpolate => false) { run = true }
 
       @set.alias_command 'bar', 'foo'
-      @set['bar'].options[:shellwords].should == @set['foo'].options[:shellwords]
-      @set['bar'].options[:interpolate].should == @set['foo'].options[:interpolate]
+      expect(@set['bar'].options[:shellwords]).to eq @set['foo'].options[:shellwords]
+      expect(@set['bar'].options[:interpolate]).to eq @set['foo'].options[:interpolate]
 
       # however some options should not be inherited
-      @set['bar'].options[:listing].should_not ==  @set['foo'].options[:listing]
-      @set['bar'].options[:listing].should == "bar"
+      expect(@set['bar'].options[:listing]).not_to eq  @set['foo'].options[:listing]
+      expect(@set['bar'].options[:listing]).to eq "bar"
     end
 
     it 'should be able to specify alias\'s description when aliasing' do
@@ -212,11 +211,11 @@ describe Pry::CommandSet do
       @set.command('foo', 'stuff') { run = true }
 
       @set.alias_command 'bar', 'foo', :desc => "tobina"
-      @set['bar'].match.should == 'bar'
-      @set['bar'].description.should == "tobina"
+      expect(@set['bar'].match).to eq 'bar'
+      expect(@set['bar'].description).to eq "tobina"
 
       @set.run_command @ctx, 'bar'
-      run.should == true
+      expect(run).to eq true
     end
 
     it "should be able to alias a command by its invocation line" do
@@ -224,19 +223,19 @@ describe Pry::CommandSet do
       @set.command(/^foo1/, 'stuff', :listing => 'foo') { run = true }
 
       @set.alias_command 'bar', 'foo1'
-      @set['bar'].match.should == 'bar'
-      @set['bar'].description.should == 'Alias for `foo1`'
+      expect(@set['bar'].match).to eq 'bar'
+      expect(@set['bar'].description).to eq 'Alias for `foo1`'
 
       @set.run_command @ctx, 'bar'
-      run.should == true
+      expect(run).to eq true
     end
 
     it "should be able to specify options when creating alias" do
       run = false
       @set.command(/^foo1/, 'stuff', :listing => 'foo') { run = true }
 
-      @set.alias_command /^b.r/, 'foo1', :listing => "bar"
-      @set.to_hash[/^b.r/].options[:listing].should == "bar"
+      @set.alias_command(/^b.r/, 'foo1', :listing => "bar")
+      expect(@set.to_hash[/^b.r/].options[:listing]).to eq "bar"
     end
 
     it "should set description to default if description parameter is nil" do
@@ -244,7 +243,7 @@ describe Pry::CommandSet do
       @set.command(/^foo1/, 'stuff', :listing => 'foo') { run = true }
 
       @set.alias_command "bar", 'foo1'
-      @set["bar"].description.should == "Alias for `foo1`"
+      expect(@set["bar"].description).to eq "Alias for `foo1`"
     end
   end
 
@@ -252,32 +251,32 @@ describe Pry::CommandSet do
     @set.command('foo', 'bar') {}
     @set.desc 'foo', 'baz'
 
-    @set['foo'].description.should == 'baz'
+    expect(@set['foo'].description).to eq 'baz'
   end
 
   it 'should get the descriptions of commands' do
     @set.command('foo', 'bar') {}
-    @set.desc('foo').should == 'bar'
+    expect(@set.desc('foo')).to eq 'bar'
   end
 
   it 'should get the descriptions of commands, by listing' do
     @set.command(/^foo1/, 'bar', :listing => 'foo') {}
-    @set.desc('foo').should == 'bar'
+    expect(@set.desc('foo')).to eq 'bar'
   end
 
   it 'should return Pry::Command::VOID_VALUE for commands by default' do
     @set.command('foo') { 3 }
-    @set.run_command(@ctx, 'foo').should == Pry::Command::VOID_VALUE
+    expect(@set.run_command(@ctx, 'foo')).to eq Pry::Command::VOID_VALUE
   end
 
   it 'should be able to keep return values' do
     @set.command('foo', '', :keep_retval => true) { 3 }
-    @set.run_command(@ctx, 'foo').should == 3
+    expect(@set.run_command(@ctx, 'foo')).to eq 3
   end
 
   it 'should be able to keep return values, even if return value is nil' do
     @set.command('foo', '', :keep_retval => true) { nil }
-    @set.run_command(@ctx, 'foo').should == nil
+    expect(@set.run_command(@ctx, 'foo')).to eq nil
   end
 
   it 'should be able to have its own helpers' do
@@ -285,9 +284,9 @@ describe Pry::CommandSet do
     @set.helpers { def my_helper; end }
 
     @set.run_command(@ctx, 'foo')
-    Pry::Command.subclass('foo', '', {}, Module.new)
-                .new({:target => binding})
-                .should_not(respond_to :my_helper)
+    expect(Pry::Command.subclass('foo', '', {}, Module.new)
+                .new({:target => binding}))
+                .not_to(respond_to :my_helper)
   end
 
   it 'should not recreate a new helper module when helpers is called' do
@@ -335,12 +334,12 @@ describe Pry::CommandSet do
 
   it 'should provide a :listing for a command that defaults to its name' do
     @set.command 'foo', "" do;end
-    @set['foo'].options[:listing].should == 'foo'
+    expect(@set['foo'].options[:listing]).to eq 'foo'
   end
 
   it 'should provide a :listing for a command that differs from its name' do
     @set.command 'foo', "", :listing => 'bar' do;end
-    @set['foo'].options[:listing].should == 'bar'
+    expect(@set['foo'].options[:listing]).to eq 'bar'
   end
 
   it "should provide a 'help' command" do
@@ -357,7 +356,7 @@ describe Pry::CommandSet do
       @set.command('foo') { run = true }
       @set.rename_command('bar', 'foo')
       @set.run_command(@ctx, 'bar')
-      run.should == true
+      expect(run).to eq true
     end
 
     it 'should accept listing name when renaming a command' do
@@ -365,7 +364,7 @@ describe Pry::CommandSet do
       @set.command('foo', "", :listing => 'love') { run = true }
       @set.rename_command('bar', 'love')
       @set.run_command(@ctx, 'bar')
-      run.should == true
+      expect(run).to eq true
     end
 
     it 'should raise exception trying to rename non-existent command' do
@@ -383,9 +382,9 @@ describe Pry::CommandSet do
       listing = "bing"
       @set.command('foo') { }
       @set.rename_command('bar', 'foo', :description => desc, :listing => listing, :keep_retval => true)
-      @set['bar'].description.should           == desc
-      @set['bar'].options[:listing].should     == listing
-      @set['bar'].options[:keep_retval].should == true
+      expect(@set['bar'].description).to           eq desc
+      expect(@set['bar'].options[:listing]).to     eq listing
+      expect(@set['bar'].options[:keep_retval]).to eq true
     end
   end
 
@@ -397,7 +396,7 @@ describe Pry::CommandSet do
         @set.before_command('foo') { foo << 2 }
         @set.run_command(@ctx, 'foo')
 
-        foo.should == [2, 1]
+        expect(foo).to eq [2, 1]
       end
 
       it 'should be called before the original command, using listing name' do
@@ -406,7 +405,7 @@ describe Pry::CommandSet do
         @set.before_command('foo') { foo << 2 }
         @set.run_command(@ctx, /^foo1/)
 
-        foo.should == [2, 1]
+        expect(foo).to eq [2, 1]
       end
 
       it 'should share the context with the original command' do
@@ -417,8 +416,8 @@ describe Pry::CommandSet do
         @set.before_command('foo') { before_val = target }
         @set.run_command(@ctx, 'foo')
 
-        before_val.should == @ctx[:target]
-        orig_val.should == @ctx[:target]
+        expect(before_val).to eq @ctx[:target]
+        expect(orig_val).to eq @ctx[:target]
       end
 
       it 'should work when applied multiple times' do
@@ -429,7 +428,7 @@ describe Pry::CommandSet do
         @set.before_command('foo') { foo << 4 }
         @set.run_command(@ctx, 'foo')
 
-        foo.should == [4, 3, 2, 1]
+        expect(foo).to eq [2, 3, 4, 1]
       end
 
     end
@@ -441,7 +440,7 @@ describe Pry::CommandSet do
         @set.after_command('foo') { foo << 2 }
         @set.run_command(@ctx, 'foo')
 
-        foo.should == [1, 2]
+        expect(foo).to eq [1, 2]
       end
 
       it 'should be called after the original command, using listing name' do
@@ -450,7 +449,7 @@ describe Pry::CommandSet do
         @set.after_command('foo') { foo << 2 }
         @set.run_command(@ctx, /^foo1/)
 
-        foo.should == [1, 2]
+        expect(foo).to eq [1, 2]
       end
 
       it 'should share the context with the original command' do
@@ -461,14 +460,14 @@ describe Pry::CommandSet do
         @set.after_command('foo') { after_val = target }
         @set.run_command(@ctx, 'foo')
 
-        after_val.should == @ctx[:target]
-        orig_val.should == @ctx[:target]
+        expect(after_val).to eq @ctx[:target]
+        expect(orig_val).to eq @ctx[:target]
       end
 
       it 'should determine the return value for the command' do
         @set.command('foo', 'bar', :keep_retval => true) { 1 }
         @set.after_command('foo') { 2 }
-        @set.run_command(@ctx, 'foo').should == 2
+        expect(@set.run_command(@ctx, 'foo')).to eq 2
       end
 
       it 'should work when applied multiple times' do
@@ -479,7 +478,7 @@ describe Pry::CommandSet do
         @set.after_command('foo') { foo << 4 }
         @set.run_command(@ctx, 'foo')
 
-        foo.should == [1, 2, 3, 4]
+        expect(foo).to eq [1, 2, 3, 4]
       end
     end
 
@@ -491,7 +490,7 @@ describe Pry::CommandSet do
         @set.before_command('foo') { foo << 3 }
         @set.run_command(@ctx, 'foo')
 
-        foo.should == [3, 1, 2]
+        expect(foo).to eq [3, 1, 2]
       end
 
     end
@@ -501,44 +500,44 @@ describe Pry::CommandSet do
   describe 'find_command' do
     it 'should find commands with the right string' do
       cmd = @set.command('rincewind'){ }
-      @set.find_command('rincewind').should == cmd
+      expect(@set.find_command('rincewind')).to eq cmd
     end
 
     it 'should not find commands with spaces before' do
-      cmd = @set.command('luggage'){ }
-      @set.find_command(' luggage').should == nil
+      @set.command('luggage'){ }
+      expect(@set.find_command(' luggage')).to eq nil
     end
 
     it 'should find commands with arguments after' do
       cmd = @set.command('vetinari'){ }
-      @set.find_command('vetinari --knock 3').should == cmd
+      expect(@set.find_command('vetinari --knock 3')).to eq cmd
     end
 
     it 'should find commands with names containing spaces' do
       cmd = @set.command('nobby nobbs'){ }
-      @set.find_command('nobby nobbs --steal petty-cash').should == cmd
+      expect(@set.find_command('nobby nobbs --steal petty-cash')).to eq cmd
     end
 
     it 'should find command defined by regex' do
       cmd = @set.command(/(capt|captain) vimes/i){ }
-      @set.find_command('Capt Vimes').should == cmd
+      expect(@set.find_command('Capt Vimes')).to eq cmd
     end
 
     it 'should find commands defined by regex with arguments' do
       cmd = @set.command(/(cpl|corporal) Carrot/i){ }
-      @set.find_command('cpl carrot --write-home').should == cmd
+      expect(@set.find_command('cpl carrot --write-home')).to eq cmd
     end
 
     it 'should not find commands by listing' do
-      cmd = @set.command(/werewol(f|ve)s?/, 'only once a month', :listing => "angua"){ }
-      @set.find_command('angua').should == nil
+      @set.command(/werewol(f|ve)s?/, 'only once a month', :listing => "angua"){ }
+      expect(@set.find_command('angua')).to eq nil
     end
 
     it 'should not find commands without command_prefix' do
       begin
         Pry.config.command_prefix = '%'
-        cmd = @set.command('detritus'){ }
-        @set.find_command('detritus').should == nil
+        @set.command('detritus'){ }
+        expect(@set.find_command('detritus')).to eq nil
       ensure
         Pry.config.command_prefix = ''
       end
@@ -548,37 +547,37 @@ describe Pry::CommandSet do
       begin
         Pry.config.command_prefix = '%'
         cmd = @set.command('colon', 'Sergeant Fred', :use_prefix => false){ }
-        @set.find_command('colon').should == cmd
+        expect(@set.find_command('colon')).to eq cmd
       ensure
         Pry.config.command_prefix = ''
       end
     end
 
     it "should find the command that has the longest match" do
-      cmd = @set.command(/\.(.*)/){ }
+      @set.command(/\.(.*)/){ }
       cmd2 = @set.command(/\.\|\|(.*)/){ }
-      @set.find_command('.||').should == cmd2
+      expect(@set.find_command('.||')).to eq cmd2
     end
 
     it "should find the command that has the longest name" do
-      cmd = @set.command(/\.(.*)/){ }
+      @set.command(/\.(.*)/){ }
       cmd2 = @set.command('.||'){ }
-      @set.find_command('.||').should == cmd2
+      expect(@set.find_command('.||')).to eq cmd2
     end
   end
 
   describe '.valid_command?' do
     it 'should be true for commands that can be found' do
-      cmd = @set.command('archchancellor')
-      @set.valid_command?('archchancellor of_the?(:University)').should == true
+      @set.command('archchancellor')
+      expect(@set.valid_command?('archchancellor of_the?(:University)')).to eq true
     end
 
     it 'should be false for commands that can\'' do
-      @set.valid_command?('def monkey(ape)').should == false
+      expect(@set.valid_command?('def monkey(ape)')).to eq false
     end
 
     it 'should not cause argument interpolation' do
-      cmd = @set.command('hello')
+      @set.command('hello')
       expect { @set.valid_command?('hello #{raise "futz"}') }.to_not raise_error
     end
   end
@@ -587,9 +586,9 @@ describe Pry::CommandSet do
 
     it 'should return Result.new(false) if there is no matching command' do
      result = @set.process_line('1 + 42')
-     result.command?.should == false
-     result.void_command?.should == false
-     result.retval.should == nil
+     expect(result.command?).to eq false
+     expect(result.void_command?).to eq false
+     expect(result.retval).to eq nil
     end
 
     it 'should return Result.new(true, VOID) if the command is not keep_retval' do
@@ -598,9 +597,9 @@ describe Pry::CommandSet do
       end
 
       result = @set.process_line('mrs-cake')
-      result.command?.should == true
-      result.void_command?.should == true
-      result.retval.should == Pry::Command::VOID_VALUE
+      expect(result.command?).to eq true
+      expect(result.void_command?).to eq true
+      expect(result.retval).to eq Pry::Command::VOID_VALUE
     end
 
     it 'should return Result.new(true, retval) if the command is keep_retval' do
@@ -609,9 +608,9 @@ describe Pry::CommandSet do
       end
 
       result = @set.process_line('magrat')
-      result.command?.should == true
-      result.void_command?.should == false
-      result.retval.should == 42
+      expect(result.command?).to eq true
+      expect(result.void_command?).to eq false
+      expect(result.retval).to eq 42
     end
 
     it 'should pass through context' do
@@ -621,27 +620,31 @@ describe Pry::CommandSet do
         :output => StringIO.new,
         :target => binding
       }
-      @set.create_command('agnes') do
-        define_method(:process) do
-          eval_string.should == ctx[:eval_string]
-          output.should == ctx[:output]
-          target.should == ctx[:target]
-          _pry_.should == ctx[:pry_instance]
+
+      inside = inner_scope do |probe|
+        @set.create_command('agnes') do
+          define_method(:process, &probe)
         end
+
+        @set.process_line('agnes', ctx)
       end
 
-      @set.process_line('agnes', ctx)
+      expect(inside.eval_string).to eq(ctx[:eval_string])
+      expect(inside.output).to eq(ctx[:output])
+      expect(inside.target).to eq(ctx[:target])
+      expect(inside._pry_).to eq(ctx[:pry_instance])
     end
 
     it 'should add command_set to context' do
-      set = @set
-      @set.create_command(/nann+y ogg+/) do
-        define_method(:process) do
-          command_set.should == set
+      inside = inner_scope do |probe|
+        @set.create_command(/nann+y ogg+/) do
+          define_method(:process, &probe)
         end
+
+        @set.process_line('nannnnnny oggggg')
       end
 
-      @set.process_line('nannnnnny oggggg')
+      expect(inside.command_set).to eq(@set)
     end
   end
 
@@ -649,12 +652,12 @@ describe Pry::CommandSet do
     describe '.complete' do
       it "should list all command names" do
         @set.create_command('susan'){ }
-        @set.complete('sus').should.include 'susan '
+        expect(@set.complete('sus')).to.include 'susan '
       end
 
       it "should delegate to commands" do
         @set.create_command('susan'){ def complete(search); ['--foo']; end }
-        @set.complete('susan ').should == ['--foo']
+        expect(@set.complete('susan ')).to eq ['--foo']
       end
     end
   end
