@@ -14,7 +14,7 @@ describe "Pry::Command" do
         #
       end
 
-      mock_command(cmd, %w(hello world)).output.should =~ /install-command ford-prefect/
+      expect(mock_command(cmd, %w(hello world)).output).to match(/install-command ford-prefect/)
     end
 
     it 'should abort early if arguments are required' do
@@ -32,7 +32,7 @@ describe "Pry::Command" do
         end
       end
 
-      mock_command(cmd).return.should == Pry::Command::VOID_VALUE
+      expect(mock_command(cmd).return).to eq Pry::Command::VOID_VALUE
     end
 
     it 'should return the return value with keep_retval' do
@@ -42,32 +42,69 @@ describe "Pry::Command" do
         end
       end
 
-      mock_command(cmd).return.should == 5
+      expect(mock_command(cmd).return).to eq 5
     end
 
-    it 'should call hooks in the right order' do
-      cmd = @set.create_command 'marvin', "Pained by the diodes in his left side" do
-        def process
-          output.puts 3 + args[0].to_i
+    context "deprecated API" do
+      it "should call hooks in the right order" do
+        cmd = @set.create_command 'marvin', "Pained by the diodes in his left side" do
+          def process
+            output.puts 1 + args[0].to_i
+          end
+        end
+
+        @set.before_command 'marvin' do |i|
+          output.puts 3 - i.to_i
+        end
+
+        @set.before_command 'marvin' do |i|
+          output.puts 4 - i.to_i
+        end
+
+        @set.after_command 'marvin' do |i|
+          output.puts 2 + i.to_i
+        end
+
+        @set.after_command 'marvin' do |i|
+          output.puts 3 + i.to_i
+        end
+
+        expect(mock_command(cmd, %w(2)).output).to eq "1\n2\n3\n4\n5\n"
+      end
+    end
+
+    context "hooks API" do
+      before do
+        @set.create_command 'jamaica', 'Out of Many, One People' do
+          def process
+            output.puts 1 + args[0].to_i
+          end
         end
       end
 
-      @set.before_command 'marvin' do |i|
-        output.puts 2 + i.to_i
-      end
-      @set.before_command 'marvin' do |i|
-        output.puts 1 + i.to_i
-      end
+      let(:hooks) {
+        h = Pry::Hooks.new
+        h.add_hook('before_jamaica', 'name1') do |i|
+          output.puts 3 - i.to_i
+        end
 
-      @set.after_command 'marvin' do |i|
-        output.puts 4 + i.to_i
-      end
+        h.add_hook('before_jamaica', 'name2') do |i|
+          output.puts 4 - i.to_i
+        end
 
-      @set.after_command 'marvin' do |i|
-        output.puts 5 + i.to_i
-      end
+        h.add_hook('after_jamaica', 'name3') do |i|
+          output.puts 2 + i.to_i
+        end
 
-      mock_command(cmd, %w(2)).output.should == "3\n4\n5\n6\n7\n"
+        h.add_hook('after_jamaica', 'name4') do |i|
+          output.puts 3 + i.to_i
+        end
+      }
+
+      it "should call hooks in the right order" do
+        out = pry_tester(hooks: hooks, commands: @set).process_command('jamaica 2')
+        expect(out).to eq("1\n2\n3\n4\n5\n")
+      end
     end
 
     # TODO: This strikes me as rather silly...
@@ -82,7 +119,7 @@ describe "Pry::Command" do
         10
       end
 
-      mock_command(cmd).return.should == 10
+      expect(mock_command(cmd).return).to eq 10
     end
   end
 
@@ -92,7 +129,7 @@ describe "Pry::Command" do
         #
       end
 
-      mock_command(@set['help'], %w(oolon-colluphid), :command_set => @set).output.should =~ /Raving Atheist/
+      expect(mock_command(@set['help'], %w(oolon-colluphid), :command_set => @set).output).to match(/Raving Atheist/)
     end
 
     it 'should use slop to generate the help for classy commands' do
@@ -102,7 +139,7 @@ describe "Pry::Command" do
         end
       end
 
-      mock_command(@set['help'], %w(eddie), :command_set => @set).output.should =~ /Over-cheerful/
+      expect(mock_command(@set['help'], %w(eddie), :command_set => @set).output).to match(/Over-cheerful/)
     end
 
     it 'should provide --help for classy commands' do
@@ -112,7 +149,7 @@ describe "Pry::Command" do
         end
       end
 
-      mock_command(cmd, %w(--help)).output.should =~ /--retaliate/
+      expect(mock_command(cmd, %w(--help)).output).to match(/--retaliate/)
     end
 
     it 'should provide a -h for classy commands' do
@@ -122,7 +159,7 @@ describe "Pry::Command" do
         end
       end
 
-      mock_command(cmd, %w(--help)).output.should =~ /Total Perspective Vortex/
+      expect(mock_command(cmd, %w(--help)).output).to match(/Total Perspective Vortex/)
     end
 
     it 'should use the banner provided' do
@@ -132,36 +169,52 @@ describe "Pry::Command" do
         BANNER
       end
 
-      mock_command(cmd, %w(--help)).output.should =~ /Who\'s merest/
+      expect(mock_command(cmd, %w(--help)).output).to match(/Who\'s merest/)
     end
   end
 
   describe 'context' do
-    context = {
-      :target => binding,
-      :output => StringIO.new,
-      :eval_string => "eval-string",
-      :command_set => @set,
-      :pry_instance => Pry.new
+    let(:context) {
+      {
+        :target => binding,
+        :output => StringIO.new,
+        :eval_string => "eval-string",
+        :command_set => @set,
+        :pry_instance => Pry.new
+      }
     }
 
-    it 'should capture lots of stuff from the hash passed to new before setup' do
-      cmd = @set.create_command 'fenchurch', "Floats slightly off the ground" do
-        define_method(:setup) do
-          self.context.should == context
-          target.should == context[:target]
-          target_self.should == context[:target].eval('self')
-          output.should == context[:output]
+    describe '#setup' do
+      it 'should capture lots of stuff from the hash passed to new before setup' do
+        inside = inner_scope do |probe|
+          cmd = @set.create_command('fenchurch', "Floats slightly off the ground") do
+            define_method(:setup, &probe)
+          end
+
+          cmd.new(context).call
         end
 
-        define_method(:process) do
-          eval_string.should == "eval-string"
-          command_set.should == @set
-          _pry_.should == context[:pry_instance]
-        end
+        expect(inside.context).to eq(context)
+        expect(inside.target).to eq(context[:target])
+        expect(inside.target_self).to eq(context[:target].eval('self'))
+        expect(inside.output).to eq(context[:output])
       end
+    end
 
-      cmd.new(context).call
+    describe '#process' do
+      it 'should capture lots of stuff from the hash passed to new before setup' do
+        inside = inner_scope do |probe|
+          cmd = @set.create_command('fenchurch', "Floats slightly off the ground") do
+            define_method(:process, &probe)
+          end
+
+          cmd.new(context).call
+        end
+
+        expect(inside.eval_string).to eq("eval-string")
+        expect(inside.__send__(:command_set)).to eq(@set)
+        expect(inside._pry_).to eq(context[:pry_instance])
+      end
     end
   end
 
@@ -186,7 +239,7 @@ describe "Pry::Command" do
         end
       end
 
-      mock_command(cmd).output.should == "setup\nsubcommands\noptions\nprocess\n"
+      expect(mock_command(cmd).output).to eq "setup\nsubcommands\noptions\nprocess\n"
     end
 
     it 'should raise a command error if process is not overridden' do
@@ -206,7 +259,7 @@ describe "Pry::Command" do
         end
       end
 
-      mock_command(cmd).return.should == 5
+      expect(mock_command(cmd).return).to eq 5
     end
 
     it 'should provide opts and args as provided by slop' do
@@ -216,22 +269,23 @@ describe "Pry::Command" do
         end
 
         def process
-          args.should == ['four']
-          opts[:f].should == 4
+          output.puts args.inspect
+          output.puts opts[:f]
         end
       end
 
-      mock_command(cmd, %w(--four 4 four))
+      result = mock_command(cmd, %w(--four 4 four))
+      expect(result.output.split).to eq ['["four"]', '4']
     end
 
     it 'should allow overriding options after definition' do
-      cmd = @set.create_command /number-(one|two)/, "Lieutenants of the Golgafrinchan Captain", :shellwords => false do
+      cmd = @set.create_command(/number-(one|two)/, "Lieutenants of the Golgafrinchan Captain", :shellwords => false) do
 
         command_options :listing => 'number-one'
       end
 
-      cmd.command_options[:shellwords].should == false
-      cmd.command_options[:listing].should == 'number-one'
+      expect(cmd.command_options[:shellwords]).to eq false
+      expect(cmd.command_options[:listing]).to eq 'number-one'
     end
 
     it "should create subcommands" do
@@ -241,12 +295,13 @@ describe "Pry::Command" do
         end
 
         def process
-          opts.fetch_command(:blahblah).should == nil
-          opts.fetch_command(:yell).present?.should == true
+          output.puts opts.fetch_command(:blahblah).inspect
+          output.puts opts.fetch_command(:yell).present?
         end
       end
 
-      mock_command(cmd, ['yell'])
+      result = mock_command(cmd, ['yell'])
+      expect(result.output.split).to eq ['nil', 'true']
     end
 
     it "should create subcommand options" do
@@ -258,13 +313,14 @@ describe "Pry::Command" do
         end
 
         def process
-          args.should == ['papa']
-          opts.fetch_command(:yell).present?.should == true
-          opts.fetch_command(:yell).person?.should == true
+          output.puts args.inspect
+          output.puts opts.fetch_command(:yell).present?
+          output.puts opts.fetch_command(:yell).person?
         end
       end
 
-      mock_command(cmd, %w|yell --person papa|)
+      result = mock_command(cmd, %w|yell --person papa|)
+      expect(result.output.split).to eq ['["papa"]', 'true', 'true']
     end
 
     it "should accept top-level arguments" do
@@ -285,69 +341,68 @@ describe "Pry::Command" do
       before do
         @x = Class.new(Pry::ClassCommand) do
           options :baby => :pig
-          match /goat/
+          match(/goat/)
           description "waaaninngggiiigygygygygy"
         end
       end
 
       it 'subclasses should inherit options, match and description from superclass' do
         k = Class.new(@x)
-        k.options.should == @x.options
-        k.match.should == @x.match
-        k.description.should == @x.description
+        expect(k.options).to eq @x.options
+        expect(k.match).to eq @x.match
+        expect(k.description).to eq @x.description
       end
     end
   end
 
   describe 'tokenize' do
     it 'should interpolate string with #{} in them' do
-      cmd = @set.command 'random-dent' do |*args|
-        args.should == ["3", "8"]
-      end
+      expect { |probe|
+        cmd = @set.command('random-dent', &probe)
 
-      foo = 5
-
-      cmd.new(:target => binding).process_line 'random-dent #{1 + 2} #{3 + foo}'
+        _foo = 5
+        cmd.new(:target => binding).process_line 'random-dent #{1 + 2} #{3 + _foo}'
+      }.to yield_with_args('3', '8')
     end
 
     it 'should not fail if interpolation is not needed and target is not set' do
-      cmd = @set.command 'the-book' do |*args|
-        args.should == ['--help']
-      end
+      expect { |probe|
+        cmd = @set.command('the-book', &probe)
 
-      cmd.new.process_line 'the-book --help'
+        cmd.new.process_line 'the-book --help'
+      }.to yield_with_args('--help')
     end
 
     it 'should not interpolate commands with :interpolate => false' do
-      cmd = @set.command 'thor', 'norse god', :interpolate => false do |*args|
-        args.should == ['%(#{foo})']
-      end
+      expect { |probe|
+        cmd = @set.command('thor', 'norse god', :interpolate => false, &probe)
 
-      cmd.new.process_line 'thor %(#{foo})'
+        cmd.new.process_line 'thor %(#{foo})'
+      }.to yield_with_args('%(#{foo})')
     end
 
     it 'should use shell-words to split strings' do
-      cmd = @set.command 'eccentrica' do |*args|
-        args.should == ['gallumbits', 'eroticon', '6']
-      end
+      expect { |probe|
+        cmd = @set.command('eccentrica', &probe)
 
-      cmd.new.process_line %(eccentrica "gallumbits" 'erot''icon' 6)
+        cmd.new.process_line %(eccentrica "gallumbits" 'erot''icon' 6)
+      }.to yield_with_args('gallumbits', 'eroticon', '6')
     end
 
     it 'should split on spaces if shellwords is not used' do
-      cmd = @set.command 'bugblatter-beast', 'would eat its grandmother', :shellwords => false do |*args|
-        args.should == ['"of', 'traal"']
-      end
+      expect { |probe|
+        cmd = @set.command('bugblatter-beast', 'would eat its grandmother', :shellwords => false, &probe)
 
-      cmd.new.process_line %(bugblatter-beast "of traal")
+        cmd.new.process_line %(bugblatter-beast "of traal")
+      }.to yield_with_args('"of', 'traal"')
     end
 
     it 'should add captures to arguments for regex commands' do
-      cmd = @set.command /perfectly (normal)( beast)?/i do |*args|
-        args.should == ['Normal', ' Beast', '(honest!)']
-      end
+      expect { |probe|
+        cmd = @set.command(/perfectly (normal)( beast)?/i, &probe)
 
-      cmd.new.process_line %(Perfectly Normal Beast (honest!))
+        cmd.new.process_line %(Perfectly Normal Beast (honest!))
+      }.to yield_with_args('Normal', ' Beast', '(honest!)')
     end
   end
 
@@ -356,15 +411,15 @@ describe "Pry::Command" do
       old = Pry.config.collision_warning
       Pry.config.collision_warning = true
 
-      cmd = @set.command 'frankie' do
+      cmd = @set.command '_frankie' do
 
       end
 
-      frankie = 'boyle'
+      _frankie = 'boyle'
       output = StringIO.new
-      cmd.new(:target => binding, :output => output).process_line %(frankie mouse)
+      cmd.new(:target => binding, :output => output).process_line %(_frankie mouse)
 
-      output.string.should =~ /command .* conflicts/
+      expect(output.string).to match(/command .* conflicts/)
 
       Pry.config.collision_warning = old
     end
@@ -380,20 +435,20 @@ describe "Pry::Command" do
       output = StringIO.new
       cmd.new(:target => binding, :output => output).process_line %(frankie = mouse)
 
-      output.string.should =~ /command .* conflicts/
+      expect(output.string).to match(/command .* conflicts/)
 
       Pry.config.collision_warning = old
     end
 
     it "should set the commands' arg_string and captures" do
+      inside = inner_scope { |probe|
+        cmd = @set.command(/benj(ie|ei)/, &probe)
 
-      cmd = @set.command /benj(ie|ei)/ do |*args|
-        self.arg_string.should == "mouse"
-        self.captures.should == ['ie']
-        args.should == ['ie', 'mouse']
-      end
+        cmd.new.process_line %(benjie mouse)
+      }
 
-      cmd.new.process_line %(benjie mouse)
+      expect(inside.arg_string).to eq("mouse")
+      expect(inside.captures).to eq(['ie'])
     end
 
     it "should raise an error if the line doesn't match the command" do
@@ -406,7 +461,7 @@ describe "Pry::Command" do
     before do
       @context = Object.new
       @set.command "walking-spanish", "down the hall", :takes_block => true do
-        PryTestHelpers.inject_var(:@x, command_block.call, target)
+        insert_variable(:@x, command_block.call, target)
       end
       @set.import Pry::Commands
 
@@ -420,39 +475,39 @@ describe "Pry::Command" do
         end
       EOS
 
-      @context.instance_variable_get(:@x).should == :jesus
+      expect(@context.instance_variable_get(:@x)).to eq :jesus
     end
 
     it 'should accept normal parameters along with block' do
       @set.block_command "walking-spanish",
           "litella's been screeching for a blind pig.",
           :takes_block => true do |x, y|
-        PryTestHelpers.inject_var(:@x, x, target)
-        PryTestHelpers.inject_var(:@y, y, target)
-        PryTestHelpers.inject_var(:@block_var, command_block.call, target)
+        insert_variable(:@x, x, target)
+        insert_variable(:@y, y, target)
+        insert_variable(:@block_var, command_block.call, target)
       end
 
       @t.eval 'walking-spanish john carl| { :jesus }'
 
-      @context.instance_variable_get(:@x).should == "john"
-      @context.instance_variable_get(:@y).should == "carl"
-      @context.instance_variable_get(:@block_var).should == :jesus
+      expect(@context.instance_variable_get(:@x)).to eq "john"
+      expect(@context.instance_variable_get(:@y)).to eq "carl"
+      expect(@context.instance_variable_get(:@block_var)).to eq :jesus
     end
 
     describe "single line blocks" do
       it 'should accept blocks with do ; end' do
         @t.eval 'walking-spanish | do ; :jesus; end'
-        @context.instance_variable_get(:@x).should == :jesus
+        expect(@context.instance_variable_get(:@x)).to eq :jesus
       end
 
       it 'should accept blocks with do; end' do
         @t.eval 'walking-spanish | do; :jesus; end'
-        @context.instance_variable_get(:@x).should == :jesus
+        expect(@context.instance_variable_get(:@x)).to eq :jesus
       end
 
       it 'should accept blocks with { }' do
         @t.eval 'walking-spanish | { :jesus }'
-        @context.instance_variable_get(:@x).should == :jesus
+        expect(@context.instance_variable_get(:@x)).to eq :jesus
       end
     end
 
@@ -461,34 +516,34 @@ describe "Pry::Command" do
       describe "arg_string" do
         it 'should remove block-related content from arg_string (with one normal arg)' do
           @set.block_command "walking-spanish", "down the hall", :takes_block => true do |x, y|
-            PryTestHelpers.inject_var(:@arg_string, arg_string, target)
-            PryTestHelpers.inject_var(:@x, x, target)
+            insert_variable(:@arg_string, arg_string, target)
+            insert_variable(:@x, x, target)
           end
 
           @t.eval 'walking-spanish john| { :jesus }'
 
-          @context.instance_variable_get(:@arg_string).should == @context.instance_variable_get(:@x)
+          expect(@context.instance_variable_get(:@arg_string)).to eq @context.instance_variable_get(:@x)
         end
 
         it 'should remove block-related content from arg_string (with no normal args)' do
           @set.block_command "walking-spanish", "down the hall", :takes_block => true do
-            PryTestHelpers.inject_var(:@arg_string, arg_string, target)
+            insert_variable(:@arg_string, arg_string, target)
           end
 
           @t.eval 'walking-spanish | { :jesus }'
 
-          @context.instance_variable_get(:@arg_string).should == ""
+          expect(@context.instance_variable_get(:@arg_string)).to eq ""
         end
 
         it 'should NOT remove block-related content from arg_string when :takes_block => false' do
           block_string = "| { :jesus }"
           @set.block_command "walking-spanish", "homemade special", :takes_block => false do
-            PryTestHelpers.inject_var(:@arg_string, arg_string, target)
+            insert_variable(:@arg_string, arg_string, target)
           end
 
           @t.eval "walking-spanish #{block_string}"
 
-          @context.instance_variable_get(:@arg_string).should == block_string
+          expect(@context.instance_variable_get(:@arg_string)).to eq block_string
         end
       end
 
@@ -496,26 +551,26 @@ describe "Pry::Command" do
         describe "block_command" do
           it "should remove block-related content from arguments" do
             @set.block_command "walking-spanish", "glass is full of sand", :takes_block => true do |x, y|
-              PryTestHelpers.inject_var(:@x, x, target)
-              PryTestHelpers.inject_var(:@y, y, target)
+              insert_variable(:@x, x, target)
+              insert_variable(:@y, y, target)
             end
 
             @t.eval 'walking-spanish | { :jesus }'
 
-            @context.instance_variable_get(:@x).should == nil
-            @context.instance_variable_get(:@y).should == nil
+            expect(@context.instance_variable_get(:@x)).to eq nil
+            expect(@context.instance_variable_get(:@y)).to eq nil
           end
 
           it "should NOT remove block-related content from arguments if :takes_block => false" do
             @set.block_command "walking-spanish", "litella screeching for a blind pig", :takes_block => false do |x, y|
-              PryTestHelpers.inject_var(:@x, x, target)
-              PryTestHelpers.inject_var(:@y, y, target)
+              insert_variable(:@x, x, target)
+              insert_variable(:@y, y, target)
             end
 
             @t.eval 'walking-spanish | { :jesus }'
 
-            @context.instance_variable_get(:@x).should == "|"
-            @context.instance_variable_get(:@y).should == "{"
+            expect(@context.instance_variable_get(:@x)).to eq "|"
+            expect(@context.instance_variable_get(:@y)).to eq "{"
           end
         end
 
@@ -523,29 +578,29 @@ describe "Pry::Command" do
           it "should remove block-related content from arguments" do
             @set.create_command "walking-spanish", "punk sanders carved one out of wood", :takes_block => true do
               def process(x, y)
-                PryTestHelpers.inject_var(:@x, x, target)
-                PryTestHelpers.inject_var(:@y, y, target)
+                insert_variable(:@x, x, target)
+                insert_variable(:@y, y, target)
               end
             end
 
             @t.eval 'walking-spanish | { :jesus }'
 
-            @context.instance_variable_get(:@x).should == nil
-            @context.instance_variable_get(:@y).should == nil
+            expect(@context.instance_variable_get(:@x)).to eq nil
+            expect(@context.instance_variable_get(:@y)).to eq nil
           end
 
           it "should NOT remove block-related content from arguments if :takes_block => false" do
             @set.create_command "walking-spanish", "down the hall", :takes_block => false do
               def process(x, y)
-                PryTestHelpers.inject_var(:@x, x, target)
-                PryTestHelpers.inject_var(:@y, y, target)
+                insert_variable(:@x, x, target)
+                insert_variable(:@y, y, target)
               end
             end
 
             @t.eval 'walking-spanish | { :jesus }'
 
-            @context.instance_variable_get(:@x).should == "|"
-            @context.instance_variable_get(:@y).should == "{"
+            expect(@context.instance_variable_get(:@x)).to eq "|"
+            expect(@context.instance_variable_get(:@y)).to eq "{"
           end
         end
       end
@@ -555,12 +610,12 @@ describe "Pry::Command" do
       describe "{} style blocks" do
         it 'should accept multiple parameters' do
           @set.block_command "walking-spanish", "down the hall", :takes_block => true do
-            PryTestHelpers.inject_var(:@x, command_block.call(1, 2), target)
+            insert_variable(:@x, command_block.call(1, 2), target)
           end
 
           @t.eval 'walking-spanish | { |x, y| [x, y] }'
 
-          @context.instance_variable_get(:@x).should == [1, 2]
+          expect(@context.instance_variable_get(:@x)).to eq [1, 2]
         end
       end
 
@@ -568,7 +623,7 @@ describe "Pry::Command" do
         it 'should accept multiple parameters' do
           @set.create_command "walking-spanish", "litella", :takes_block => true do
             def process
-              PryTestHelpers.inject_var(:@x, command_block.call(1, 2), target)
+              insert_variable(:@x, command_block.call(1, 2), target)
             end
           end
 
@@ -578,7 +633,7 @@ describe "Pry::Command" do
             end
           EOS
 
-          @context.instance_variable_get(:@x).should == [1, 2]
+          expect(@context.instance_variable_get(:@x)).to eq [1, 2]
         end
       end
     end
@@ -586,7 +641,7 @@ describe "Pry::Command" do
     describe "closure behaviour" do
       it 'should close over locals in the definition context' do
         @t.eval 'var = :hello', 'walking-spanish | { var }'
-        @context.instance_variable_get(:@x).should == :hello
+        expect(@context.instance_variable_get(:@x)).to eq :hello
       end
     end
 
@@ -594,12 +649,12 @@ describe "Pry::Command" do
       describe "block_command" do
         it "should expose block in command_block method" do
           @set.block_command "walking-spanish", "glass full of sand", :takes_block => true do
-            PryTestHelpers.inject_var(:@x, command_block.call, target)
+            insert_variable(:@x, command_block.call, target)
           end
 
           @t.eval 'walking-spanish | { :jesus }'
 
-          @context.instance_variable_get(:@x).should == :jesus
+          expect(@context.instance_variable_get(:@x)).to eq :jesus
         end
       end
 
@@ -618,13 +673,13 @@ describe "Pry::Command" do
         it "should expose block in command_block method" do
           @set.create_command "walking-spanish", "homemade special", :takes_block => true do
             def process
-              PryTestHelpers.inject_var(:@x, command_block.call, target)
+              insert_variable(:@x, command_block.call, target)
             end
           end
 
           @t.eval 'walking-spanish | { :jesus }'
 
-          @context.instance_variable_get(:@x).should == :jesus
+          expect(@context.instance_variable_get(:@x)).to eq :jesus
         end
       end
     end
@@ -634,11 +689,13 @@ describe "Pry::Command" do
 
     before do
       class MyTestCommand < Pry::ClassCommand
-        match /my-*test/
+        match(/my-*test/)
         description 'So just how many sound technicians does it take to' \
           'change a lightbulb? 1? 2? 3? 1-2-3? Testing?'
         options :shellwords => false, :listing => 'my-test'
 
+        undef process if method_defined? :process
+
         def process
           output.puts command_name * 2
         end
@@ -652,11 +709,11 @@ describe "Pry::Command" do
     end
 
     it "allows creation of custom subclasses of Pry::Command" do
-      pry_eval('my---test').should =~ /my-testmy-test/
+      expect(pry_eval('my---test')).to match(/my-testmy-test/)
     end
 
     it "shows the source of the process method" do
-      pry_eval('show-source my-test').should =~ /output.puts command_name/
+      expect(pry_eval('show-source my-test')).to match(/output.puts command_name/)
     end
 
     describe "command options hash" do
@@ -671,7 +728,7 @@ describe "Pry::Command" do
           :use_prefix        => true,
           :takes_block       => false
         }
-        MyTestCommand.options.should == options_hash
+        expect(MyTestCommand.options).to eq options_hash
       end
 
       describe ":listing option" do
@@ -682,7 +739,7 @@ describe "Pry::Command" do
           end
           Pry.config.commands.add_command HappyNewYear
 
-          HappyNewYear.options[:listing].should == 'happy-new-year'
+          expect(HappyNewYear.options[:listing]).to eq 'happy-new-year'
 
           Pry.config.commands.delete 'happy-new-year'
         end
@@ -695,7 +752,7 @@ describe "Pry::Command" do
           end
           Pry.config.commands.add_command MerryChristmas
 
-          MerryChristmas.options[:listing].should == 'happy-holidays'
+          expect(MerryChristmas.options[:listing]).to eq 'happy-holidays'
 
           Pry.config.commands.delete 'merry-christmas'
         end
@@ -707,9 +764,9 @@ describe "Pry::Command" do
           end
           Pry.config.commands.add_command CoolWinter
 
-          CoolWinter.options[:listing].should == '/.*winter/'
+          expect(CoolWinter.options[:listing]).to eq '/.*winter/'
 
-          Pry.config.commands.delete /.*winter/
+          Pry.config.commands.delete(/.*winter/)
         end
       end
     end
@@ -732,7 +789,7 @@ describe "Pry::Command" do
           end
         end
 
-        create_command /[Hh]ello-world/, "desc" do
+        create_command(/[Hh]ello-world/, "desc") do
           def process
             state.my_state ||= 0
             state.my_state += 2
@@ -746,25 +803,25 @@ describe "Pry::Command" do
 
     it 'should save state for the command on the Pry#command_state hash' do
       @t.eval 'litella'
-      @t.pry.command_state["litella"].my_state.should == 1
+      expect(@t.pry.command_state["litella"].my_state).to eq 1
     end
 
     it 'should ensure state is maintained between multiple invocations of command' do
       @t.eval 'litella'
       @t.eval 'litella'
-      @t.pry.command_state["litella"].my_state.should == 2
+      expect(@t.pry.command_state["litella"].my_state).to eq 2
     end
 
     it 'should ensure state with same name stored seperately for each command' do
       @t.eval 'litella', 'sanders'
 
-      @t.pry.command_state["litella"].my_state.should == 1
-      @t.pry.command_state["sanders"].my_state.should =="wood"
+      expect(@t.pry.command_state["litella"].my_state).to eq 1
+      expect(@t.pry.command_state["sanders"].my_state).to eq("wood")
     end
 
     it 'should ensure state is properly saved for regex commands' do
       @t.eval 'hello-world', 'Hello-world'
-      @t.pry.command_state[/[Hh]ello-world/].my_state.should == 4
+      expect(@t.pry.command_state[/[Hh]ello-world/].my_state).to eq 4
     end
   end
 
@@ -779,7 +836,7 @@ describe "Pry::Command" do
           end
         end
 
-        @set.complete('torrid ').should.include('--test ')
+        expect(@set.complete('torrid ')).to.include('--test ')
       end
     end
   end
@@ -794,17 +851,17 @@ describe "Pry::Command" do
     end
 
     it 'should be correct for default commands' do
-      @set["help"].group.should == "Help"
+      expect(@set["help"].group).to eq "Help"
     end
 
     it 'should not change once it is initialized' do
       @set["magic"].group("-==CD COMMAND==-")
-      @set["magic"].group.should == "Not for a public use"
+      expect(@set["magic"].group).to eq "Not for a public use"
     end
 
     it 'should not disappear after the call without parameters' do
       @set["magic"].group
-      @set["magic"].group.should == "Not for a public use"
+      expect(@set["magic"].group).to eq "Not for a public use"
     end
   end
 end
