@@ -16,7 +16,6 @@ describe "edit" do
   end
 
   describe "with FILE" do
-
     before do
       # OS-specific tempdir name. For GNU/Linux it's "tmp", for Windows it's
       # something "Temp".
@@ -32,7 +31,7 @@ describe "edit" do
     end
 
     after do
-      FileUtils.rm(@tf_path) if File.exists?(@tf_path)
+      FileUtils.rm(@tf_path) if File.exist?(@tf_path)
     end
 
     it "should not allow patching any known kind of file" do
@@ -44,32 +43,32 @@ describe "edit" do
 
     it "should invoke Pry.config.editor with absolutified filenames" do
       pry_eval 'edit lib/pry.rb'
-      @file.should == File.expand_path('lib/pry.rb')
+      expect(@file).to eq File.expand_path('lib/pry.rb')
 
       pry_eval "edit #@tf_path"
-      @file.should == @tf_path
+      expect(@file).to eq @tf_path
     end
 
     it "should guess the line number from a colon" do
       pry_eval 'edit lib/pry.rb:10'
-      @line.should == 10
+      expect(@line).to eq 10
     end
 
     it "should use the line number from -l" do
       pry_eval 'edit -l 10 lib/pry.rb'
-      @line.should == 10
+      expect(@line).to eq 10
     end
 
     it "should not delete the file!" do
       pry_eval 'edit Rakefile'
-      File.exist?(@file).should == true
+      expect(File.exist?(@file)).to eq true
     end
 
     it "works with files that contain blanks in their names" do
       tf_path = File.join(File.dirname(@tf_path), 'swoop and doop.rb')
       FileUtils.touch(tf_path)
       pry_eval "edit #{ tf_path }"
-      @file.should == tf_path
+      expect(@file).to eq tf_path
       FileUtils.rm(tf_path)
     end
 
@@ -85,7 +84,7 @@ describe "edit" do
           nil
         }
         pry_eval "edit #@tf_path"
-        Pad.required.should == true
+        expect(Pad.required).to eq true
       end
     end
 
@@ -105,7 +104,7 @@ describe "edit" do
 
           pry_eval "edit #{path}"
 
-          Pad.counter.should == counter + 1
+          expect(Pad.counter).to eq counter + 1
         end
       end
 
@@ -116,7 +115,7 @@ describe "edit" do
 
           pry_eval "edit #{path}"
 
-          Pad.counter.should == counter
+          expect(Pad.counter).to eq counter
         end
       end
 
@@ -125,7 +124,9 @@ describe "edit" do
           counter = Pad.counter
           path    = tf.path
 
-          Pad.counter.should == counter
+          pry_eval "edit -n #{path}"
+
+          expect(Pad.counter).to eq counter
         end
       end
 
@@ -136,7 +137,7 @@ describe "edit" do
 
           pry_eval "edit -r #{path}"
 
-          Pad.counter.should == counter + 1
+          expect(Pad.counter).to eq counter + 1
         end
       end
     end
@@ -152,9 +153,9 @@ describe "edit" do
 
       it "should pass the editor a reloading arg" do
         pry_eval 'edit lib/pry.rb'
-        @reloading.should == true
+        expect(@reloading).to eq true
         pry_eval 'edit -n lib/pry.rb'
-        @reloading.should == false
+        expect(@reloading).to eq false
       end
     end
   end
@@ -173,7 +174,7 @@ describe "edit" do
       before do
         @tf = Tempfile.new(["pry", ".rb"])
         @path = @tf.path
-        @tf << "1\n2\nraise RuntimeError"
+        @tf << "_foo = 1\n_bar = 2\nraise RuntimeError"
         @tf.flush
 
         begin
@@ -185,7 +186,7 @@ describe "edit" do
 
       after do
         @tf.close(true)
-        File.unlink("#{@path}c") if File.exists?("#{@path}c") #rbx
+        File.unlink("#{@path}c") if File.exist?("#{@path}c") #rbx
       end
 
       it "should reload the file" do
@@ -197,11 +198,11 @@ describe "edit" do
           nil
         }
 
-        defined?(FOO).should equal nil
+        expect(defined?(FOO)).to equal nil
 
         @t.eval 'edit --ex'
 
-        FOO.should == 'BAR'
+        expect(FOO).to eq 'BAR'
       end
 
       # regression test (this used to edit the current method instead
@@ -221,7 +222,7 @@ describe "edit" do
           Object.new.pry
         end
 
-        source_location.should == [@path, 3]
+        expect(source_location).to eq [@path, 3]
         Pad.clear
       end
 
@@ -231,11 +232,11 @@ describe "edit" do
           nil
         }
 
-        defined?(FOO2).should equal nil
+        expect(defined?(FOO2)).to equal nil
 
         @t.eval 'edit -n --ex'
 
-        defined?(FOO2).should equal nil
+        expect(defined?(FOO2)).to equal nil
       end
 
       describe "with --patch" do
@@ -247,15 +248,15 @@ describe "edit" do
             nil
           }
 
-          defined?(FOO3).should equal nil
+          expect(defined?(FOO3)).to equal nil
 
           @t.eval 'edit --ex --patch'
 
-          FOO3.should == 'PIYO'
+          expect(FOO3).to eq 'PIYO'
 
           @tf.rewind
-          @tf.read.should == "1\n2\nraise RuntimeError"
-          @patched_def.should == "FOO3 = 'PIYO'"
+          expect(@tf.read).to eq "_foo = 1\n_bar = 2\nraise RuntimeError"
+          expect(@patched_def).to eq "FOO3 = 'PIYO'"
         end
       end
     end
@@ -273,26 +274,26 @@ describe "edit" do
 
       it 'should start on first level of backtrace with just --ex' do
         @t.eval 'edit -n --ex'
-        @__ex_file__.should == "a"
-        @__ex_line__.should == 1
+        expect(@__ex_file__).to eq "a"
+        expect(@__ex_line__).to eq 1
       end
 
       it 'should start editor on first level of backtrace with --ex 0' do
         @t.eval 'edit -n --ex 0'
-        @__ex_file__.should == "a"
-        @__ex_line__.should == 1
+        expect(@__ex_file__).to eq "a"
+        expect(@__ex_line__).to eq 1
       end
 
       it 'should start editor on second level of backtrace with --ex 1' do
         @t.eval 'edit -n --ex 1'
-        @__ex_file__.should == "b"
-        @__ex_line__.should == 2
+        expect(@__ex_file__).to eq "b"
+        expect(@__ex_line__).to eq 2
       end
 
       it 'should start editor on third level of backtrace with --ex 2' do
         @t.eval 'edit -n --ex 2'
-        @__ex_file__.should == "c"
-        @__ex_line__.should == 3
+        expect(@__ex_file__).to eq "c"
+        expect(@__ex_line__).to eq 3
       end
 
       it 'should display error message when backtrace level is invalid' do
@@ -309,29 +310,32 @@ describe "edit" do
     it "should edit the current expression if it's incomplete" do
       @t.push 'def a'
       @t.process_command 'edit'
-      @contents.should == "def a\n"
+      expect(@contents).to eq "def a\n"
     end
 
     it "should edit the previous expression if the current is empty" do
+      @t.eval 'undef a if self.singleton_class.method_defined? :a'
       @t.eval 'def a; 2; end', 'edit'
-      @contents.should == "def a; 2; end\n"
+      expect(@contents).to eq "def a; 2; end\n"
     end
 
     it "should use a blank file if -t is specified" do
+      @t.eval 'undef a if self.singleton_class.method_defined? :a'
       @t.eval 'def a; 5; end', 'edit -t'
-      @contents.should == "\n"
+      expect(@contents).to eq "\n"
     end
 
     it "should use a blank file if -t given, even during an expression" do
       @t.push 'def a;'
       @t.process_command 'edit -t'
-      @contents.should == "\n"
+      expect(@contents).to eq "\n"
     end
 
     it "should position the cursor at the end of the expression" do
+      @t.eval 'undef a if self.singleton_class.method_defined? :a'
       @t.eval "def a; 2;\nend"
       @t.process_command 'edit'
-      @line.should == 2
+      expect(@line).to eq 2
     end
 
     it "should evaluate the expression" do
@@ -340,7 +344,7 @@ describe "edit" do
         nil
       }
       @t.process_command 'edit'
-      @t.eval_string.should == "'FOO'\n"
+      expect(@t.eval_string).to eq "'FOO'\n"
     end
 
     it "should ignore -n for tempfiles" do
@@ -349,7 +353,7 @@ describe "edit" do
         nil
       }
       @t.process_command "edit -n"
-      @t.eval_string.should == "'FOO'\n"
+      expect(@t.eval_string).to eq "'FOO'\n"
     end
 
     it "should not evaluate a file with -n" do
@@ -359,8 +363,8 @@ describe "edit" do
       }
       begin
         @t.process_command 'edit -n spec/fixtures/foo.rb'
-        File.read("spec/fixtures/foo.rb").should == "'FOO'\n"
-        @t.eval_string.should == ''
+        expect(File.read("spec/fixtures/foo.rb")).to eq "'FOO'\n"
+        expect(@t.eval_string).to eq ''
       ensure
         FileUtils.rm "spec/fixtures/foo.rb"
       end
@@ -370,22 +374,22 @@ describe "edit" do
   describe "with --in" do
     it "should edit the nth line of _in_" do
       pry_eval '10', '11', 'edit --in -2'
-      @contents.should == "10\n"
+      expect(@contents).to eq "10\n"
     end
 
     it "should edit the last line if no argument is given" do
       pry_eval '10', '11', 'edit --in'
-      @contents.should == "11\n"
+      expect(@contents).to eq "11\n"
     end
 
     it "should edit a range of lines if a range is given" do
       pry_eval "10", "11", "edit -i 1,2"
-      @contents.should == "10\n11\n"
+      expect(@contents).to eq "10\n11\n"
     end
 
     it "should edit a multi-line expression as it occupies one line of _in_" do
-      pry_eval "class Fixnum\n  def invert; -self; end\nend", "edit -i 1"
-      @contents.should == "class Fixnum\n  def invert; -self; end\nend\n"
+      pry_eval "class #{1.class}\n  def invert; -self; end\nend", "edit -i 1"
+      expect(@contents).to eq "class #{1.class}\n  def invert; -self; end\nend\n"
     end
 
     it "should not work with a filename" do
@@ -397,9 +401,60 @@ describe "edit" do
     end
   end
 
+  describe 'when editing a method by name' do
+    def use_editor(tester, options)
+      tester.pry.config.editor = lambda do |filename, line|
+        File.open(filename, 'w') { |f| f.write options.fetch(:replace_all) }
+        nil
+      end
+      tester
+    end
+
+    it 'uses patch editing on methods that were previously patched' do
+      # initial definition
+      tester   = pry_tester binding
+      filename = __FILE__
+      line     = __LINE__ + 2
+      klass    = Class.new do
+        def m; 1; end
+      end
+      expect(klass.new.m).to eq 1
+
+      # now patch it
+      use_editor(tester, replace_all: 'def m; 2; end').eval('edit --patch klass#m')
+      expect(klass.new.m).to eq 2
+
+      # edit by name, no --patch
+      use_editor(tester, replace_all: 'def m; 3; end').eval("edit klass#m")
+      expect(klass.new.m).to eq 3
+
+      # original file is unchanged
+      expect(File.readlines(filename)[line-1].strip).to eq 'def m; 1; end'
+    end
+
+    it 'can repeatedly edit methods that were defined in the console' do
+      # initial definition
+      tester = pry_tester binding
+      tester.eval("klass = Class.new do\n"\
+                  "  def m; 1; end\n"\
+                  "end")
+      expect(tester.eval("klass.new.m")).to eq 1
+
+      # first edit
+      use_editor(tester, replace_all: 'def m; 2; end').eval('edit klass#m')
+      expect(tester.eval('klass.new.m')).to eq 2
+
+      # repeat edit
+      use_editor(tester, replace_all: 'def m; 3; end').eval('edit klass#m')
+      expect(tester.eval('klass.new.m')).to eq 3
+    end
+  end
+
   describe "old edit-method tests now migrated to edit" do
     describe "on a method defined in a file" do
       before do
+        Object.remove_const :X if defined? ::X
+        Object.remove_const :A if defined? ::A
         @tempfile = (Tempfile.new(['pry', '.rb']))
         @tempfile.puts <<-EOS
         module A
@@ -436,7 +491,7 @@ describe "edit" do
             G = :nawt
 
             def foo
-              :possibly
+              _foo = :possibly
               G
             end
           end
@@ -464,33 +519,33 @@ describe "edit" do
         it "should correctly find a class method" do
           pry_eval 'edit X.x'
 
-          @file.should == @tempfile_path
-          @line.should == 14
+          expect(@file).to eq @tempfile_path
+          expect(@line).to eq 14
 
         end
 
         it "should correctly find an instance method" do
           pry_eval 'edit X#x'
-          @file.should == @tempfile_path
-          @line.should == 18
+          expect(@file).to eq @tempfile_path
+          expect(@line).to eq 18
         end
 
         it "should correctly find a method on an instance" do
           pry_eval 'x = X.new', 'edit x.x'
-          @file.should == @tempfile_path
-          @line.should == 18
+          expect(@file).to eq @tempfile_path
+          expect(@line).to eq 18
         end
 
         it "should correctly find a method from a module" do
           pry_eval 'edit X#a'
-          @file.should == @tempfile_path
-          @line.should == 2
+          expect(@file).to eq @tempfile_path
+          expect(@line).to eq 2
         end
 
         it "should correctly find an aliased method" do
           pry_eval 'edit X#c'
-          @file.should == @tempfile_path
-          @line.should == 22
+          expect(@file).to eq @tempfile_path
+          expect(@line).to eq 22
         end
       end
 
@@ -498,7 +553,11 @@ describe "edit" do
         before do
           Pry.config.editor = lambda do |file, line|
             lines = File.read(file).lines.to_a
-            lines[1] = ":maybe\n"
+            lines[1] = if lines[2] =~ /end/
+                         ":maybe\n"
+                       else
+                         "_foo = :maybe\n"
+                       end
             File.open(file, 'w') do |f|
               f.write(lines.join)
             end
@@ -513,44 +572,44 @@ describe "edit" do
           class << X
             X.method(:x).owner.should == self
           end
-          X.method(:x).receiver.should == X
-          X.x.should == :maybe
+          expect(X.method(:x).receiver).to eq X
+          expect(X.x).to eq :maybe
         end
 
         it "should successfully replace an instance method" do
           pry_eval 'edit -p X#x'
 
-          X.instance_method(:x).owner.should == X
-          X.new.x.should == :maybe
+          expect(X.instance_method(:x).owner).to eq X
+          expect(X.new.x).to eq :maybe
         end
 
         it "should successfully replace a method on an instance" do
           pry_eval 'instance = X.new', 'edit -p instance.x'
 
           instance = X.new
-          instance.method(:x).owner.should == X
-          instance.x.should == :maybe
+          expect(instance.method(:x).owner).to eq X
+          expect(instance.x).to eq :maybe
         end
 
         it "should successfully replace a method from a module" do
           pry_eval 'edit -p X#a'
 
-          X.instance_method(:a).owner.should == A
-          X.new.a.should == :maybe
+          expect(X.instance_method(:a).owner).to eq A
+          expect(X.new.a).to eq :maybe
         end
 
         it "should successfully replace a method with a question mark" do
           pry_eval 'edit -p X#y?'
 
-          X.instance_method(:y?).owner.should == X
-          X.new.y?.should == :maybe
+          expect(X.instance_method(:y?).owner).to eq X
+          expect(X.new.y?).to eq :maybe
         end
 
         it "should preserve module nesting" do
           pry_eval 'edit -p X::B#foo'
 
-          X::B.instance_method(:foo).owner.should == X::B
-          X::B.new.foo.should == :nawt
+          expect(X::B.instance_method(:foo).owner).to eq X::B
+          expect(X::B.new.foo).to eq :nawt
         end
 
         describe "monkey-patching" do
@@ -562,7 +621,7 @@ describe "edit" do
           # @return [String] the stripped line from the tempfile at +lineno+
           def stripped_line_at(lineno)
             @tempfile.rewind
-            @tempfile.lines.to_a[lineno].strip
+            @tempfile.each_line.to_a[lineno].strip
           end
 
           # Applies the monkey patch for +method+ with help of evaluation of
@@ -589,54 +648,54 @@ describe "edit" do
             def_before, def_after =
               apply_monkey_patch(X.method(:x), "#@edit X.x")
 
-            def_before.should   == ':double_yup'
-            def_after.should    == ':double_yup'
-            @patched_def.should == ':maybe'
+            expect(def_before).to   eq ':double_yup'
+            expect(def_after).to    eq ':double_yup'
+            expect(@patched_def).to eq ':maybe'
           end
 
           it "should work for an instance method" do
             def_before, def_after =
               apply_monkey_patch(X.instance_method(:x), "#@edit X#x")
 
-            def_before.should   == ':nope'
-            def_after.should    == ':nope'
-            @patched_def.should == ':maybe'
+            expect(def_before).to   eq ':nope'
+            expect(def_after).to    eq ':nope'
+            expect(@patched_def).to eq ':maybe'
           end
 
           it "should work for a method on an instance" do
             def_before, def_after =
               apply_monkey_patch(X.instance_method(:x), 'instance = X.new', "#@edit instance.x")
 
-            def_before.should   == ':nope'
-            def_after.should    == ':nope'
-            @patched_def.should == ':maybe'
+            expect(def_before).to   eq ':nope'
+            expect(def_after).to    eq ':nope'
+            expect(@patched_def).to eq ':maybe'
           end
 
           it "should work for a method from a module" do
             def_before, def_after =
               apply_monkey_patch(X.instance_method(:a), "#@edit X#a")
 
-            def_before.should   == ':yup'
-            def_after.should    == ':yup'
-            @patched_def.should == ':maybe'
+            expect(def_before).to   eq ':yup'
+            expect(def_after).to    eq ':yup'
+            expect(@patched_def).to eq ':maybe'
           end
 
           it "should work for a method with a question mark" do
             def_before, def_after =
               apply_monkey_patch(X.instance_method(:y?), "#@edit X#y?")
 
-            def_before.should   == ':because'
-            def_after.should    == ':because'
-            @patched_def.should == ':maybe'
+            expect(def_before).to   eq ':because'
+            expect(def_after).to    eq ':because'
+            expect(@patched_def).to eq ':maybe'
           end
 
           it "should work with nesting" do
             def_before, def_after =
               apply_monkey_patch(X::B.instance_method(:foo), "#@edit X::B#foo")
 
-            def_before.should   == ':possibly'
-            def_after.should    == ':possibly'
-            @patched_def.should == ':maybe'
+            expect(def_before).to   eq '_foo = :possibly'
+            expect(def_after).to    eq '_foo = :possibly'
+            expect(@patched_def).to eq '_foo = :maybe'
           end
         end
       end
@@ -659,10 +718,10 @@ describe "edit" do
           pry_eval 'edit -p X#c'
 
 
-          Pry::Method.from_str("X#c").alias?.should == true
+          expect(Pry::Method.from_str("X#c").alias?).to eq true
 
-          X.new.b.should == :kinda
-          X.new.c.should == :kindaaa
+          expect(X.new.b).to eq :kinda
+          expect(X.new.c).to eq :kindaaa
           $x = nil
         end
       end
@@ -678,9 +737,9 @@ describe "edit" do
 
         it "should pass the editor a reloading arg" do
           pry_eval 'edit X.x'
-          @reloading.should == true
+          expect(@reloading).to eq true
           pry_eval 'edit -n X.x'
-          @reloading.should == false
+          expect(@reloading).to eq false
         end
       end
     end
@@ -697,7 +756,7 @@ describe "edit" do
         }
 
         def m2
-          :jeremy_jones
+          _foo = :jeremy_jones
           binding
         end
       end
@@ -709,7 +768,7 @@ describe "edit" do
 
     it 'should edit method context' do
       Pry.config.editor = lambda do |file, line|
-        [file, line].should == BinkyWink.instance_method(:m2).source_location
+        expect([file, line]).to eq BinkyWink.instance_method(:m2).source_location
         nil
       end
 
@@ -719,7 +778,7 @@ describe "edit" do
 
     it 'errors when cannot find method context' do
       Pry.config.editor = lambda do |file, line|
-        [file, line].should == BinkyWink.instance_method(:m1).source_location
+        expect([file, line]).to eq BinkyWink.instance_method(:m1).source_location
         nil
       end
 
