@@ -18,25 +18,29 @@ describe "find-method" do
 
   describe "find matching methods by name regex (-n option)" do
     it "should find a method by regex" do
-      pry_eval(binding, "find-method hell MyKlass").should =~
+      expect(pry_eval(binding, "find-method hell MyKlass")).to match(
         /MyKlass.*?hello/m
+      )
     end
 
     it "should NOT match a method that does not match the regex" do
-      pry_eval(binding, "find-method hell MyKlass").should_not =~
+      expect(pry_eval(binding, "find-method hell MyKlass")).not_to match(
         /MyKlass.*?goodbye/m
+      )
     end
   end
 
   describe "find matching methods by content regex (-c option)" do
     it "should find a method by regex" do
-      pry_eval(binding, "find-method -c timothy MyKlass").should =~
+      expect(pry_eval(binding, "find-method -c timothy MyKlass")).to match(
         /MyKlass.*?hello/m
+      )
     end
 
     it "should NOT match a method that does not match the regex" do
-      pry_eval(binding, "find-method timothy MyKlass").should_not =~
+      expect(pry_eval(binding, "find-method timothy MyKlass")).not_to match(
         /MyKlass.*?goodbye/m
+      )
     end
   end
 
@@ -46,16 +50,17 @@ describe "find-method" do
       raise "mooo"
     end
 
-    pry_eval(binding, "find-method -c timothy MyKlass").should =~
+    expect(pry_eval(binding, "find-method -c timothy MyKlass")).to match(
       /MyKlass.*?hello/m
+    )
   end
 
   it "should escape regexes correctly" do
     good = /tea_time\?/
     bad  = /tea_tim\?/
-    pry_eval(binding, 'find-method tea_time? MyKlass').should =~ good
-    pry_eval(binding, 'find-method tea_time? MyKlass').should =~ good
-    pry_eval(binding, 'find-method tea_time\? MyKlass').should_not =~ bad
-    pry_eval(binding, 'find-method tea_time\? MyKlass').should =~ good
+    expect(pry_eval(binding, 'find-method tea_time? MyKlass')).to match(good)
+    expect(pry_eval(binding, 'find-method tea_time? MyKlass')).to match(good)
+    expect(pry_eval(binding, 'find-method tea_time\? MyKlass')).not_to match(bad)
+    expect(pry_eval(binding, 'find-method tea_time\? MyKlass')).to match(good)
   end
 end
