@@ -1,82 +1,98 @@
 require_relative '../helper'
 
 describe "ls" do
+  describe "bug #1407" do
+    it "behaves as usual when a method of the same name exists." do
+      expect(
+        pry_eval("def ls; 5; end", "ls")
+      ).to match(/self\.methods: /)
+      pry_eval("undef ls")
+    end
+  end
+
   describe "below ceiling" do
     it "should stop before Object by default" do
-      pry_eval("cd Class.new{ def goo; end }.new", "ls").should_not =~ /Object/
-      pry_eval("cd Class.new{ def goo; end }", "ls -M").should_not =~ /Object/
+      expect(pry_eval("cd Class.new{ def goo; end }.new", "ls")).not_to match(/Object/)
+      expect(pry_eval("cd Class.new{ def goo; end }", "ls -M")).not_to match(/Object/)
     end
 
     it "should include object if -v is given" do
-      pry_eval("cd Class.new{ def goo; end }.new", "ls -m -v").should =~ /Object/
-      pry_eval("cd Class.new{ def goo; end }", "ls -vM").should =~ /Object/
+      expect(pry_eval("cd Class.new{ def goo; end }.new", "ls -m -v")).to match(/Object/)
+      expect(pry_eval("cd Class.new{ def goo; end }", "ls -vM")).to match(/Object/)
     end
 
     it "should include super-classes by default" do
-      pry_eval(
+      expect(pry_eval(
         "cd Class.new(Class.new{ def goo; end; public :goo }).new",
-        "ls").should =~ /goo/
+        "ls")).to match(/goo/)
 
-      pry_eval(
+      expect(pry_eval(
         "cd Class.new(Class.new{ def goo; end; public :goo })",
-        "ls -M").should =~ /goo/
+        "ls -M")).to match(/goo/)
     end
 
     it "should not include super-classes when -q is given" do
-      pry_eval("cd Class.new(Class.new{ def goo; end }).new", "ls -q").should_not =~ /goo/
-      pry_eval("cd Class.new(Class.new{ def goo; end })", "ls -M -q").should_not =~ /goo/
+      expect(pry_eval("cd Class.new(Class.new{ def goo; end }).new", "ls -q")).not_to match(/goo/)
+      expect(pry_eval("cd Class.new(Class.new{ def goo; end })", "ls -M -q")).not_to match(/goo/)
     end
   end
 
   describe "help" do
     it 'should show help with -h' do
-      pry_eval("ls -h").should =~ /Usage: ls/
+      expect(pry_eval("ls -h")).to match(/Usage: ls/)
     end
   end
 
   describe "BasicObject" do
     it "should work on BasicObject" do
-      pry_eval("ls BasicObject.new").should =~ /BasicObject#methods:.*__send__/m
+      expect(pry_eval("ls BasicObject.new")).to match(/BasicObject#methods:.*__send__/m)
     end
 
     it "should work on subclasses of BasicObject" do
-      pry_eval(
+      expect(pry_eval(
         "class LessBasic < BasicObject; def jaroussky; 5; end; end",
         "ls LessBasic.new"
-      ).should =~ /LessBasic#methods:.*jaroussky/m
+      )).to match(/LessBasic#methods:.*jaroussky/m)
     end
   end
 
   describe "immediates" do
-    it "should work on Fixnum" do
-      pry_eval("ls 5").should =~ /Fixnum#methods:.*modulo/m
+    # Ruby 2.4+
+    if 5.class.name == 'Integer'
+      it "should work on Integer" do
+        expect(pry_eval("ls 5")).to match(/Integer#methods:.*modulo/m)
+      end
+    else
+      it "should work on Fixnum" do
+        expect(pry_eval("ls 5")).to match(/Fixnum#methods:.*modulo/m)
+      end
     end
   end
 
   describe "methods" do
     it "should show public methods by default" do
       output = pry_eval("ls Class.new{ def goo; end; public :goo }.new")
-      output.should =~ /methods: goo/
+      expect(output).to match(/methods: goo/)
     end
 
     it "should not show protected/private by default" do
-      pry_eval("ls -M Class.new{ def goo; end; private :goo }").should_not =~ /goo/
-      pry_eval("ls Class.new{ def goo; end; protected :goo }.new").should_not =~ /goo/
+      expect(pry_eval("ls -M Class.new{ def goo; end; private :goo }")).not_to match(/goo/)
+      expect(pry_eval("ls Class.new{ def goo; end; protected :goo }.new")).not_to match(/goo/)
     end
 
     it "should show public methods with -p" do
-      pry_eval("ls -p Class.new{ def goo; end }.new").should =~ /methods: goo/
+      expect(pry_eval("ls -p Class.new{ def goo; end }.new")).to match(/methods: goo/)
     end
 
     it "should show protected/private methods with -p" do
-      pry_eval("ls -pM Class.new{ def goo; end; protected :goo }").should =~ /methods: goo/
-      pry_eval("ls -p Class.new{ def goo; end; private :goo }.new").should =~ /methods: goo/
+      expect(pry_eval("ls -pM Class.new{ def goo; end; protected :goo }")).to match(/methods: goo/)
+      expect(pry_eval("ls -p Class.new{ def goo; end; private :goo }.new")).to match(/methods: goo/)
     end
 
     it "should work for objects with an overridden method method" do
       require 'net/http'
       # This doesn't actually touch the network, promise!
-      pry_eval("ls Net::HTTP::Get.new('localhost')").should =~ /Net::HTTPGenericRequest#methods/
+      expect(pry_eval("ls Net::HTTP::Get.new('localhost')")).to match(/Net::HTTPGenericRequest#methods/)
     end
 
     it "should work for objects which instance_variables returns array of symbol but there is no Symbol#downcase" do
@@ -105,7 +121,7 @@ describe "ls" do
     unless Pry::Helpers::BaseHelpers.rbx?
       it "should handle classes that (pathologically) define .ancestors" do
         output = pry_eval("ls Class.new{ def self.ancestors; end; def hihi; end }")
-        output.should =~ /hihi/
+        expect(output).to match(/hihi/)
       end
     end
   end
@@ -113,38 +129,38 @@ describe "ls" do
   describe 'with -l' do
     focus 'should find locals and sort by descending size' do
       result = pry_eval(Object.new, "aa = 'asdf'; bb = 'xyz'", 'ls -l')
-      result.should_not =~ /=>/
-      result.should_not =~ /0x\d{5}/
-      result.should =~ /asdf.*xyz/m
+      expect(result).not_to match(/=>/)
+      expect(result).not_to match(/0x\d{5}/)
+      expect(result).to match(/asdf.*xyz/m)
     end
     it 'should not list pry noise' do
-      pry_eval('ls -l').should_not =~ /_(?:dir|file|ex|pry|out|in)_/
+      expect(pry_eval('ls -l')).not_to match(/_(?:dir|file|ex|pry|out|in)_/)
     end
   end
 
   describe "when inside Modules" do
     it "should still work" do
-      pry_eval(
+      expect(pry_eval(
         "cd Module.new{ def foobie; end; public :foobie }",
-        "ls -M").should =~ /foobie/
+        "ls -M")).to match(/foobie/)
     end
 
     it "should work for ivars" do
-      pry_eval(
+      expect(pry_eval(
         "module StigmaT1sm; def foobie; @@gharble = 456; end; end",
         "Object.new.tap{ |o| o.extend(StigmaT1sm) }.foobie",
         "cd StigmaT1sm",
-        "ls -i").should =~ /@@gharble/
+        "ls -i")).to match(/@@gharble/)
     end
 
     it "should include instance methods by default" do
       output = pry_eval(
         "ls Module.new{ def shinanagarns; 4; end; public :shinanagarns }")
-      output.should =~ /shinanagarns/
+      expect(output).to match(/shinanagarns/)
     end
 
     it "should behave normally when invoked on Module itself" do
-      pry_eval("ls Module").should_not =~ /Pry/
+      expect(pry_eval("ls Module")).not_to match(/Pry/)
     end
   end
 
@@ -152,20 +168,20 @@ describe "ls" do
     it "works on top-level" do
       toplevel_consts = pry_eval('ls -c')
       [/RUBY_PLATFORM/, /ARGF/, /STDOUT/].each do |const|
-        toplevel_consts.should =~ const
+        expect(toplevel_consts).to match(const)
       end
     end
 
     it "should show constants defined on the current module" do
-      pry_eval("class TempFoo1; BARGHL = 1; end", "ls TempFoo1").should =~ /BARGHL/
+      expect(pry_eval("class TempFoo1; BARGHL = 1; end", "ls TempFoo1")).to match(/BARGHL/)
     end
 
     it "should not show constants defined on parent modules by default" do
-      pry_eval("class TempFoo2; LHGRAB = 1; end; class TempFoo3 < TempFoo2; BARGHL = 1; end", "ls TempFoo3").should_not =~ /LHGRAB/
+      expect(pry_eval("class TempFoo2; LHGRAB = 1; end; class TempFoo3 < TempFoo2; BARGHL = 1; end", "ls TempFoo3")).not_to match(/LHGRAB/)
     end
 
     it "should show constants defined on ancestors with -v" do
-      pry_eval("class TempFoo4; LHGRAB = 1; end; class TempFoo5 < TempFoo4; BARGHL = 1; end", "ls -v TempFoo5").should =~ /LHGRAB/
+      expect(pry_eval("class TempFoo4; LHGRAB = 1; end; class TempFoo5 < TempFoo4; BARGHL = 1; end", "ls -v TempFoo5")).to match(/LHGRAB/)
     end
 
     it "should not autoload constants!" do
@@ -174,22 +190,22 @@ describe "ls" do
     end
 
     it "should show constants for an object's class regardless of mixins" do
-      pry_eval(
+      expect(pry_eval(
         "cd Pry.new",
         "extend Module.new",
         "ls -c"
-      ).should match(/Method/)
+      )).to match(/Method/)
     end
   end
 
   describe "grep" do
     it "should reduce the number of outputted things" do
-      pry_eval("ls -c Object").should =~ /ArgumentError/
-      pry_eval("ls -c Object --grep Run").should_not =~ /ArgumentError/
+      expect(pry_eval("ls -c Object")).to match(/ArgumentError/)
+      expect(pry_eval("ls -c Object --grep Run")).not_to match(/ArgumentError/)
     end
 
     it "should still output matching things" do
-      pry_eval("ls -c Object --grep Run").should =~ /RuntimeError/
+      expect(pry_eval("ls -c Object --grep Run")).to match(/RuntimeError/)
     end
   end
 
@@ -198,33 +214,33 @@ describe "ls" do
       # rubinius has a bug that means local_variables of "main" aren't reported inside eval()
       unless Pry::Helpers::BaseHelpers.rbx?
         it "should show local variables" do
-          pry_eval("ls").should =~ /_pry_/
-          pry_eval("arbitrar = 1", "ls").should =~ /arbitrar/
+          expect(pry_eval("ls")).to match(/_pry_/)
+          expect(pry_eval("arbitrar = 1", "ls")).to match(/arbitrar/)
         end
       end
     end
 
     describe "when in a class" do
       it "should show constants" do
-        pry_eval("class GeFromulate1; FOOTIFICATE=1.3; end", "cd GeFromulate1", "ls").should =~ /FOOTIFICATE/
+        expect(pry_eval("class GeFromulate1; FOOTIFICATE=1.3; end", "cd GeFromulate1", "ls")).to match(/FOOTIFICATE/)
       end
 
       it "should show class variables" do
-        pry_eval("class GeFromulate2; @@flurb=1.3; end", "cd GeFromulate2", "ls").should =~ /@@flurb/
+        expect(pry_eval("class GeFromulate2; @@flurb=1.3; end", "cd GeFromulate2", "ls")).to match(/@@flurb/)
       end
 
       it "should show methods" do
-        pry_eval("class GeFromulate3; def self.mooflight; end ; end", "cd GeFromulate3", "ls").should =~ /mooflight/
+        expect(pry_eval("class GeFromulate3; def self.mooflight; end ; end", "cd GeFromulate3", "ls")).to match(/mooflight/)
       end
     end
 
     describe "when in an object" do
       it "should show methods" do
-        pry_eval("cd Class.new{ def self.fooerise; end; self }", "ls").should =~ /fooerise/
+        expect(pry_eval("cd Class.new{ def self.fooerise; end; self }", "ls")).to match(/fooerise/)
       end
 
       it "should show instance variables" do
-        pry_eval("cd Class.new", "@alphooent = 1", "ls").should =~ /@alphooent/
+        expect(pry_eval("cd Class.new", "@alphooent = 1", "ls")).to match(/@alphooent/)
       end
     end
   end
@@ -232,13 +248,13 @@ describe "ls" do
   if Pry::Helpers::BaseHelpers.jruby?
     describe 'on java objects' do
       it 'should omit java-esque aliases by default' do
-        pry_eval('ls java.lang.Thread.current_thread').should =~ /\bthread_group\b/
-        pry_eval('ls java.lang.Thread.current_thread').should_not =~ /\bgetThreadGroup\b/
+        expect(pry_eval('ls java.lang.Thread.current_thread')).to match(/\bthread_group\b/)
+        expect(pry_eval('ls java.lang.Thread.current_thread')).not_to match(/\bgetThreadGroup\b/)
       end
 
       it 'should include java-esque aliases if requested' do
-        pry_eval('ls java.lang.Thread.current_thread -J').should =~ /\bthread_group\b/
-        pry_eval('ls java.lang.Thread.current_thread -J').should =~ /\bgetThreadGroup\b/
+        expect(pry_eval('ls java.lang.Thread.current_thread -J')).to match(/\bthread_group\b/)
+        expect(pry_eval('ls java.lang.Thread.current_thread -J')).to match(/\bgetThreadGroup\b/)
       end
     end
   end
