@@ -6,12 +6,12 @@ describe "show-input" do
   end
 
   it 'should correctly show the current lines in the input buffer' do
-    @t.push *unindent(<<-STR).split("\n")
+    @t.push(*unindent(<<-STR).split("\n"))
       def hello
         puts :bing
     STR
 
     @t.process_command 'show-input'
-    @t.last_output.should =~ /\A\d+: def hello\n\d+:   puts :bing/
+    expect(@t.last_output).to match(/\A\d+: def hello\n\d+:   puts :bing/)
   end
 end
