@@ -1,10 +1,26 @@
 require_relative 'helper'
 describe Pry::Config do
+  describe "bug #1552" do
+    specify "a local key has precendence over its default when the stored value is false" do
+      local = Pry::Config.from_hash({}, Pry::Config.from_hash('color' => true))
+      local.color = false
+      expect(local.color).to eq(false)
+    end
+  end
+
+  describe "bug #1277" do
+    specify "a local key has precendence over an inherited method of the same name" do
+      local = Pry::Config.from_hash(output: 'foobar')
+      local.extend Module.new { def output(); 'broken'; end }
+      expect(local.output).to eq('foobar')
+    end
+  end
+
   describe "reserved keys" do
-    it "raises an ArgumentError on assignment of a reserved key" do
+    it "raises Pry::Config::ReservedKeyError on assignment of a reserved key" do
       local = Pry::Config.new
-      Pry::Config::RESERVED_KEYS.each do |key|
-        expect { local[key] = 1 }.to  raise_error ArgumentError
+      local.instance_variable_get(:@reserved_keys).each do |key|
+        expect { local[key] = 1 }.to raise_error(Pry::Config::ReservedKeyError)
       end
     end
   end
@@ -12,13 +28,13 @@ describe Pry::Config do
   describe "traversal to parent" do
     it "traverses back to the parent when a local key is not found" do
       local = Pry::Config.new Pry::Config.from_hash(foo: 1)
-      local.foo.should == 1
+      expect(local.foo).to eq(1)
     end
 
     it "stores a local key and prevents traversal to the parent" do
       local = Pry::Config.new Pry::Config.from_hash(foo: 1)
       local.foo = 2
-      local.foo.should == 2
+      expect(local.foo).to eq(2)
     end
 
     it "traverses through a chain of parents" do
@@ -26,28 +42,35 @@ describe Pry::Config do
       local1 = Pry::Config.new(root)
       local2 = Pry::Config.new(local1)
       local3 = Pry::Config.new(local2)
-      local3.foo.should == 21
+      expect(local3.foo).to eq(21)
     end
 
-    it "stores a local copy of the parent's hooks upon accessing them" do
+    it "stores a local copy of the parents hooks upon accessing them" do
       parent = Pry::Config.from_hash(hooks: "parent_hooks")
       local  = Pry::Config.new parent
       local.hooks.gsub! 'parent', 'local'
-      local.hooks.should == 'local_hooks'
-      parent.hooks.should == 'parent_hooks'
+      expect(local.hooks).to eq 'local_hooks'
+      expect(parent.hooks).to eq('parent_hooks')
     end
   end
 
   describe ".from_hash" do
     it "returns an object without a default" do
       local = Pry::Config.from_hash({})
-      local.default.should == nil
+      expect(local.default).to eq(nil)
     end
 
     it "returns an object with a default" do
       default = Pry::Config.new(nil)
       local = Pry::Config.from_hash({}, default)
-      local.default.should == local
+      expect(local.default).to eq(local)
+    end
+
+    it "recursively builds Pry::Config objects from a Hash" do
+      h = {'foo1' => {'foo2' => {'foo3' => 'foobar'}}}
+      default = Pry::Config.from_hash(h)
+      expect(default.foo1).to be_instance_of(described_class)
+      expect(default.foo1.foo2).to be_instance_of(described_class)
     end
   end
 
@@ -60,8 +83,13 @@ describe Pry::Config do
     it "returns a Method object for a dynamic key" do
       @config["key"] = 1
       method_obj = @config.method(:key)
-      method_obj.name.should == :key
-      method_obj.call.should == 1
+      expect(method_obj.name).to eq :key
+      expect(method_obj.call).to eq(1)
+    end
+
+    it "returns a Method object for a setter on a parent" do
+      config = described_class.from_hash({}, described_class.from_hash(foo: 1))
+      expect(config.method(:foo=)).to be_an_instance_of(Method)
     end
   end
 
@@ -72,24 +100,24 @@ describe Pry::Config do
 
     it "returns true for a local key" do
       @config.zzfoo = 1
-      @config.respond_to?(:zzfoo).should == true
+      expect(@config.respond_to?(:zzfoo)).to eq(true)
     end
 
     it "returns false for an unknown key" do
-      @config.respond_to?(:blahblah).should == false
+      expect(@config.respond_to?(:blahblah)).to eq(false)
     end
   end
 
   describe "#default" do
     it "returns nil" do
       local = Pry::Config.new(nil)
-      local.default.should == nil
+      expect(local.default).to eq(nil)
     end
 
     it "returns the default" do
       default = Pry::Config.new(nil)
       local = Pry::Config.new(default)
-      local.default.should == default
+      expect(local.default).to eq(default)
     end
   end
 
@@ -97,7 +125,7 @@ describe Pry::Config do
     it "returns an array of local keys" do
       root = Pry::Config.from_hash({zoo: "boo"}, nil)
       local = Pry::Config.from_hash({foo: "bar"}, root)
-      local.keys.should == ["foo"]
+      expect(local.keys).to eq(["foo"])
     end
   end
 
@@ -107,12 +135,12 @@ describe Pry::Config do
       local2 = Pry::Config.new(nil)
       local1.foo = "hi"
       local2.foo = "hi"
-      local1.should == local2
+      expect(local1).to eq(local2)
     end
 
     it "compares equality against an object who does not implement #to_hash" do
       local1 = Pry::Config.new(nil)
-      local1.should_not == Object.new
+      expect(local1).not_to eq(Object.new)
     end
   end
 
@@ -120,9 +148,9 @@ describe Pry::Config do
     it "forgets a local key" do
       local = Pry::Config.new Pry::Config.from_hash(foo: 1)
       local.foo = 2
-      local.foo.should == 2
+      expect(local.foo).to eq 2
       local.forget(:foo)
-      local.foo.should == 1
+      expect(local.foo).to eq(1)
     end
   end
 
@@ -130,13 +158,13 @@ describe Pry::Config do
     it "provides a copy of local key & value pairs as a Hash" do
       local = Pry::Config.new Pry::Config.from_hash(bar: true)
       local.foo = "21"
-      local.to_hash.should == { "foo" => "21" }
+      expect(local.to_hash).to eq({ "foo" => "21" })
     end
 
     it "returns a duplicate of the lookup table" do
       local = Pry::Config.new(nil)
       local.to_hash.merge!("foo" => 42)
-      local.foo.should_not == 42
+      expect(local.foo).not_to eq(42)
     end
   end
 
@@ -148,18 +176,18 @@ describe Pry::Config do
     it "merges an object who returns a Hash through #to_hash" do
       obj = Class.new { def to_hash() {epoch: 1} end }.new
       @config.merge!(obj)
-      @config.epoch.should == 1
+      expect(@config.epoch).to eq(1)
     end
 
     it "merges an object who returns a Hash through #to_h" do
       obj = Class.new { def to_h() {epoch: 2} end }.new
       @config.merge!(obj)
-      @config.epoch.should == 2
+      expect(@config.epoch).to eq(2)
     end
 
     it "merges a Hash" do
       @config.merge!(epoch: 420)
-      @config.epoch.should == 420
+      expect(@config.epoch).to eq(420)
     end
 
     it "raises a TypeError for objects who can't become a Hash" do
@@ -173,17 +201,13 @@ describe Pry::Config do
     end
 
     it "returns true" do
-      @local.clear.should == true
+      expect(@local.clear).to eq(true)
     end
 
     it "clears local assignments" do
       @local.foo = 1
       @local.clear
-      @local.to_hash.should == {}
-    end
-
-    it "is aliased as #refresh" do
-      @local.method(:clear).should == @local.method(:refresh)
+      expect(@local.to_hash).to eq({})
     end
   end
 
@@ -191,7 +215,27 @@ describe Pry::Config do
     it "stores keys as strings" do
       local = Pry::Config.from_hash({})
       local[:zoo] = "hello"
-      local.to_hash.should == { "zoo" => "hello" }
+      expect(local.to_hash).to eq({ "zoo" => "hello" })
+    end
+  end
+
+  describe "#[]" do
+    it "traverses back to a default" do
+      default = Pry::Config.from_hash({k: 1})
+      local = Pry::Config.new(default)
+      expect(local['k']).to eq(1)
+    end
+
+    it "traverses back to a default (2 deep)" do
+      default1 = Pry::Config.from_hash({k: 1})
+      default2 = Pry::Config.from_hash({}, default1)
+      local = Pry::Config.new(default2)
+      expect(local['k']).to eq(1)
+    end
+
+    it "traverses back to a default that doesn't exist, and returns nil" do
+      local = Pry::Config.from_hash({}, nil)
+      expect(local['output']).to eq(nil)
     end
   end
 end
