@@ -7,65 +7,65 @@ describe Pry::HistoryArray do
   end
 
   it 'should have a maximum size specifed at creation time' do
-    @array.max_size.should == 10
+    expect(@array.max_size).to eq 10
   end
 
   it 'should be able to be added objects to' do
-    @populated.size.should == 4
-    @populated.to_a.should == [1, 2, 3, 4]
+    expect(@populated.size).to eq 4
+    expect(@populated.to_a).to eq [1, 2, 3, 4]
   end
 
   it 'should be able to access single elements' do
-    @populated[2].should == 3
+    expect(@populated[2]).to eq 3
   end
 
   it 'should be able to access negative indices' do
-    @populated[-1].should == 4
+    expect(@populated[-1]).to eq 4
   end
 
   it 'should be able to access ranges' do
-    @populated[1..2].should == [2, 3]
+    expect(@populated[1..2]).to eq [2, 3]
   end
 
   it 'should be able to access ranges starting from a negative index' do
-    @populated[-2..3].should == [3, 4]
+    expect(@populated[-2..3]).to eq [3, 4]
   end
 
   it 'should be able to access ranges ending at a negative index' do
-    @populated[2..-1].should == [3, 4]
+    expect(@populated[2..-1]).to eq [3, 4]
   end
 
   it 'should be able to access ranges using only negative indices' do
-    @populated[-2..-1].should == [3, 4]
+    expect(@populated[-2..-1]).to eq [3, 4]
   end
 
   it 'should be able to use range where end is excluded' do
-    @populated[-2...-1].should == [3]
+    expect(@populated[-2...-1]).to eq [3]
   end
 
   it 'should be able to access slices using a size' do
-    @populated[-3, 2].should == [2, 3]
+    expect(@populated[-3, 2]).to eq [2, 3]
   end
 
   it 'should remove older entries' do
     11.times { |n| @array << n }
 
-    @array[0].should  == nil
-    @array[1].should  == 1
-    @array[10].should == 10
+    expect(@array[0]).to  eq nil
+    expect(@array[1]).to  eq 1
+    expect(@array[10]).to eq 10
   end
 
   it 'should not be larger than specified maximum size' do
     12.times { |n| @array << n }
-    @array.entries.compact.size.should == 10
+    expect(@array.entries.compact.size).to eq 10
   end
 
   it 'should pop!' do
     @populated.pop!
-    @populated.to_a.should == [1, 2, 3]
+    expect(@populated.to_a).to eq [1, 2, 3]
   end
 
   it 'should return an indexed hash' do
-    @populated.to_h[0].should == @populated[0]
+    expect(@populated.to_h[0]).to eq @populated[0]
   end
 end
