@@ -1,11 +1,10 @@
 require_relative 'helper'
-
-describe "The whole thing" do
+describe Pry::REPL do
   it "should let you run commands in the middle of multiline expressions" do
     ReplTester.start do
       input  'def a'
       input  '!'
-      output /^Input buffer cleared/
+      output(/^Input buffer cleared/)
 
       input  '5'
       output '=> 5'
@@ -15,14 +14,14 @@ describe "The whole thing" do
   it "should rescue exceptions" do
     ReplTester.start do
       input  'raise "lorum"'
-      output /^RuntimeError: lorum/
+      output(/^RuntimeError: lorum/)
 
       if defined?(java)
         input  'raise java.lang.Exception.new("foo")'
-        output /Exception: foo/
+        output(/Exception: foo/)
 
         input  'raise java.io.IOException.new("bar")'
-        output /IOException: bar/
+        output(/IOException: bar/)
       end
     end
   end
@@ -32,7 +31,7 @@ describe "The whole thing" do
       ReplTester.start do
         input  'Pry::REPL.new(_pry_, :target => 10).start'
         output ''
-        prompt /10.*> $/
+        prompt(/10.*> $/)
 
         input  'self'
         output '=> 10'
@@ -49,7 +48,7 @@ describe "The whole thing" do
       ReplTester.start do
         input  'Pry.start(10, _pry_.config)'
         output ''
-        prompt /10.*> $/
+        prompt(/10.*> $/)
 
         input  'self'
         output '=> 10'
@@ -66,14 +65,14 @@ describe "The whole thing" do
       ReplTester.start do
         input  'cd 10'
         output ''
-        prompt /10.*> $/
+        prompt(/10.*> $/)
 
         input  '_pry_.binding_stack.pop'
-        output /^=> #<Binding/
-        prompt /main.*> $/
+        output(/^=> #<Binding/)
+        prompt(/main.*> $/)
 
         input  '_pry_.binding_stack.pop'
-        output /^=> #<Binding/
+        output(/^=> #<Binding/)
         assert_exited
       end
     end
@@ -90,13 +89,36 @@ describe "The whole thing" do
       ReplTester.start(:commands => set) do
         input  'def x'
         output ''
-        prompt /\*   $/
+        prompt(/\*   $/)
 
         input  'hello!'
         output '=> "hello"'
-        prompt /> $/
+        prompt(/> $/)
       end
     end
   end
 
+  describe "space prefix" do
+    describe "with 1 space" do
+      it "it prioritizes variables over commands" do
+        expect(pry_eval(' ls = 2+2', ' ls')).to eq(4)
+      end
+    end
+
+    describe "with more than 1 space" do
+      it "prioritizes commands over variables" do
+        expect(mock_pry('    ls = 2+2')).to match(/SyntaxError.+unexpected '='/)
+      end
+    end
+  end
+
+  describe "#piping?" do
+    it "returns false when $stdout is a non-IO object" do
+      repl = described_class.new(Pry.new, {})
+      old_stdout = $stdout
+      $stdout = Class.new { def write(*) end }.new
+      expect(repl.send(:piping?)).to eq(false)
+      $stdout = old_stdout
+    end
+  end
 end
